HTTP adapter that uses Req for Telegram Bot API requests.
This is the recommended HTTP adapter. It uses Finch under the hood for connection pooling and provides sensible defaults for long polling.
See ExGram.Adapter behaviour for more details.
HTTP adapter that uses Req for Telegram Bot API requests.
This is the recommended HTTP adapter. It uses Finch under the hood for connection pooling and provides sensible defaults for long polling.
See ExGram.Adapter behaviour for more details.