ExGram.Encoder.EngineCompiler (ex_gram v0.65.0)

Copy Markdown View Source

Dynamically compiles the ExGram.Encoder.Engine module with the selected engine.

This allows the engine backend to be defined at compile time without reading from application config on every call.

Summary

Functions

compile(engine)