ExGram.Macros.Executer (ex_gram v0.65.0)

Copy Markdown View Source

Executer for the method macro, it takes care of checking the parameters, fetching the token, building the path and body, and calling the adapter.

Summary

Functions

execute_method(name, verb, body, file_parameters, returned_type, ops, method_ops, mandatory_types, optional_types)