ExGram.Model.AcceptedGiftTypes (ex_gram v0.64.0)

Copy Markdown View Source

This object describes the types of gifts that can be gifted to a user or a chat.

Check the documentation of this model on Telegram Bot API

  • unlimited_gifts: True, if unlimited regular gifts are accepted
  • limited_gifts: True, if limited regular gifts are accepted
  • unique_gifts: True, if unique gifts or gifts that can be upgraded to unique for free are accepted
  • premium_subscription: True, if a Telegram Premium subscription is accepted
  • gifts_from_channels: True, if transfers of unique gifts from channels are accepted

Summary

Types

t()

@type t() :: %ExGram.Model.AcceptedGiftTypes{
  gifts_from_channels: boolean(),
  limited_gifts: boolean(),
  premium_subscription: boolean(),
  unique_gifts: boolean(),
  unlimited_gifts: boolean()
}

Functions

decode_as()