ExGram.Model.Animation (ex_gram v0.64.0)

Copy Markdown View Source

This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).

Check the documentation of this model on Telegram Bot API

  • file_id: Identifier for this file, which can be used to download or reuse the file
  • file_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
  • width: Video width as defined by the sender
  • height: Video height as defined by the sender
  • duration: Duration of the video in seconds as defined by the sender
  • thumbnail (optional): Optional. Animation thumbnail as defined by the sender
  • file_name (optional): Optional. Original animation filename as defined by the sender
  • mime_type (optional): Optional. MIME type of the file as defined by the sender
  • file_size (optional): Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.

Summary

Types

t()

@type t() :: %ExGram.Model.Animation{
  duration: integer(),
  file_id: String.t(),
  file_name: String.t() | nil,
  file_size: integer() | nil,
  file_unique_id: String.t(),
  height: integer(),
  mime_type: String.t() | nil,
  thumbnail: ExGram.Model.PhotoSize.t() | nil,
  width: integer()
}

Functions

decode_as()