ExGram.Model.Audio (ex_gram v0.64.0)

Copy Markdown View Source

This object represents an audio file to be treated as music by the Telegram clients.

Check the documentation of this model on Telegram Bot API

  • file_id: Identifier for this file, which can be used to download or reuse the file
  • file_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
  • duration: Duration of the audio in seconds as defined by the sender
  • performer (optional): Optional. Performer of the audio as defined by the sender or by audio tags
  • title (optional): Optional. Title of the audio as defined by the sender or by audio tags
  • file_name (optional): Optional. Original filename as defined by the sender
  • mime_type (optional): Optional. MIME type of the file as defined by the sender
  • file_size (optional): Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
  • thumbnail (optional): Optional. Thumbnail of the album cover to which the music file belongs

Summary

Types

t()

@type t() :: %ExGram.Model.Audio{
  duration: integer(),
  file_id: String.t(),
  file_name: String.t() | nil,
  file_size: integer() | nil,
  file_unique_id: String.t(),
  mime_type: String.t() | nil,
  performer: String.t() | nil,
  thumbnail: ExGram.Model.PhotoSize.t() | nil,
  title: String.t() | nil
}

Functions

decode_as()