ExGram.Model.BackgroundFillGradient (ex_gram v0.64.0)

Copy Markdown View Source

The background is a gradient fill.

Check the documentation of this model on Telegram Bot API

  • type: Type of the background fill, always "gradient”
  • top_color: Top color of the gradient in the RGB24 format
  • bottom_color: Bottom color of the gradient in the RGB24 format
  • rotation_angle: Clockwise rotation angle of the background fill in degrees; 0-359

Summary

Types

t()

@type t() :: %ExGram.Model.BackgroundFillGradient{
  bottom_color: integer(),
  rotation_angle: integer(),
  top_color: integer(),
  type: String.t()
}

Functions

decode_as()