ExGram.Model.BackgroundFillSolid (ex_gram v0.64.0)

Copy Markdown View Source

The background is filled using the selected color.

Check the documentation of this model on Telegram Bot API

  • type: Type of the background fill, always "solid”
  • color: The color of the background fill in the RGB24 format

Summary

Types

t()

@type t() :: %ExGram.Model.BackgroundFillSolid{color: integer(), type: String.t()}

Functions

decode_as()