ExGram.Model.BackgroundTypeChatTheme (ex_gram v0.64.0)

Copy Markdown View Source

The background is taken directly from a built-in chat theme.

Check the documentation of this model on Telegram Bot API

  • type: Type of the background, always "chat_theme”
  • theme_name: Name of the chat theme, which is usually an emoji

Summary

Types

t()

@type t() :: %ExGram.Model.BackgroundTypeChatTheme{
  theme_name: String.t(),
  type: String.t()
}

Functions

decode_as()