ExGram.Model.BackgroundTypePattern (ex_gram v0.64.0)

Copy Markdown View Source

The background is a .PNG or .TGV (gzipped subset of SVG with MIME type "application/x-tgwallpattern”) pattern to be combined with the background fill chosen by the user.

Check the documentation of this model on Telegram Bot API

  • type: Type of the background, always "pattern”
  • document: Document with the pattern
  • fill: The background fill that is combined with the pattern
  • intensity: Intensity of the pattern when it is shown above the filled background; 0-100
  • is_inverted (optional): Optional. True, if the background fill must be applied only to the pattern itself. All other pixels are black in this case. For dark themes only
  • is_moving (optional): Optional. True, if the background moves slightly when the device is tilted

Summary

Types

t()

@type t() :: %ExGram.Model.BackgroundTypePattern{
  document: ExGram.Model.Document.t(),
  fill: ExGram.Model.BackgroundFill.t(),
  intensity: integer(),
  is_inverted: boolean() | nil,
  is_moving: boolean() | nil,
  type: String.t()
}

Functions

decode_as()