ExGram.Model.BackgroundTypeWallpaper (ex_gram v0.64.0)

Copy Markdown View Source

The background is a wallpaper in the JPEG format.

Check the documentation of this model on Telegram Bot API

  • type: Type of the background, always "wallpaper”
  • document: Document with the wallpaper
  • dark_theme_dimming: Dimming of the background in dark themes, as a percentage; 0-100
  • is_blurred (optional): Optional. True, if the wallpaper is downscaled to fit in a 450x450 square and then box-blurred with radius 12
  • is_moving (optional): Optional. True, if the background moves slightly when the device is tilted

Summary

Types

t()

@type t() :: %ExGram.Model.BackgroundTypeWallpaper{
  dark_theme_dimming: integer(),
  document: ExGram.Model.Document.t(),
  is_blurred: boolean() | nil,
  is_moving: boolean() | nil,
  type: String.t()
}

Functions

decode_as()