Describes the birthdate of a user.
Check the documentation of this model on Telegram Bot API
day: Day of the user's birth; 1-31month: Month of the user's birth; 1-12year (optional): Optional. Year of the user's birth
Describes the birthdate of a user.
Check the documentation of this model on Telegram Bot API
day: Day of the user's birth; 1-31month: Month of the user's birth; 1-12year (optional): Optional. Year of the user's birth