Represents the scope of bot commands, covering all group and supergroup chat administrators.
Check the documentation of this model on Telegram Bot API
type: Scope type, must be all_chat_administrators
Summary
Types
@type t() :: %ExGram.Model.BotCommandScopeAllChatAdministrators{type: String.t()}