ExGram.Model.BotCommandScopeAllGroupChats (ex_gram v0.64.0)

Copy Markdown View Source

Represents the scope of bot commands, covering all group and supergroup chats.

Check the documentation of this model on Telegram Bot API

  • type: Scope type, must be all_group_chats

Summary

Types

t()

@type t() :: %ExGram.Model.BotCommandScopeAllGroupChats{type: String.t()}

Functions

decode_as()