ExGram.Model.BotCommandScopeAllPrivateChats (ex_gram v0.64.0)

Copy Markdown View Source

Represents the scope of bot commands, covering all private chats.

Check the documentation of this model on Telegram Bot API

  • type: Scope type, must be all_private_chats

Summary

Types

t()

@type t() :: %ExGram.Model.BotCommandScopeAllPrivateChats{type: String.t()}

Functions

decode_as()