ExGram.Model.BotCommandScopeChat (ex_gram v0.64.0)

Copy Markdown View Source

Represents the scope of bot commands, covering a specific chat.

Check the documentation of this model on Telegram Bot API

  • type: Scope type, must be chat
  • chat_id: Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername). Channel direct messages chats and channel chats aren't supported.

Summary

Types

t()

@type t() :: %ExGram.Model.BotCommandScopeChat{
  chat_id: integer() | String.t(),
  type: String.t()
}

Functions

decode_as()