ExGram.Model.BotCommandScopeChatAdministrators (ex_gram v0.64.0)

Copy Markdown View Source

Represents the scope of bot commands, covering all administrators of a specific group or supergroup chat.

Check the documentation of this model on Telegram Bot API

  • type: Scope type, must be chat_administrators
  • chat_id: Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername). Channel direct messages chats and channel chats aren't supported.

Summary

Types

t()

@type t() :: %ExGram.Model.BotCommandScopeChatAdministrators{
  chat_id: integer() | String.t(),
  type: String.t()
}

Functions

decode_as()