ExGram.Model.BotCommandScopeChatMember (ex_gram v0.64.0)

Copy Markdown View Source

Represents the scope of bot commands, covering a specific member of a group or supergroup chat.

Check the documentation of this model on Telegram Bot API

  • type: Scope type, must be chat_member
  • chat_id: Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername). Channel direct messages chats and channel chats aren't supported.
  • user_id: Unique identifier of the target user

Summary

Types

t()

@type t() :: %ExGram.Model.BotCommandScopeChatMember{
  chat_id: integer() | String.t(),
  type: String.t(),
  user_id: integer()
}

Functions

decode_as()