ExGram.Model.BotCommandScopeDefault (ex_gram v0.64.0)

Copy Markdown View Source

Represents the default scope of bot commands. Default commands are used if no commands with a narrower scope are specified for the user.

Check the documentation of this model on Telegram Bot API

  • type: Scope type, must be default

Summary

Types

t()

@type t() :: %ExGram.Model.BotCommandScopeDefault{type: String.t()}

Functions

decode_as()