This object represents the bot's name.
Check the documentation of this model on Telegram Bot API
name: The bot's name
Summary
Types
@type t() :: %ExGram.Model.BotName{name: String.t()}
This object represents the bot's name.
Check the documentation of this model on Telegram Bot API
name: The bot's name@type t() :: %ExGram.Model.BotName{name: String.t()}