This object represents the bot's short description.
Check the documentation of this model on Telegram Bot API
short_description: The bot's short description
Summary
Types
@type t() :: %ExGram.Model.BotShortDescription{short_description: String.t()}
This object represents the bot's short description.
Check the documentation of this model on Telegram Bot API
short_description: The bot's short description@type t() :: %ExGram.Model.BotShortDescription{short_description: String.t()}