ExGram.Model.BusinessIntro (ex_gram v0.64.0)

Copy Markdown View Source

Contains information about the start page settings of a Telegram Business account.

Check the documentation of this model on Telegram Bot API

  • title (optional): Optional. Title text of the business intro
  • message (optional): Optional. Message text of the business intro
  • sticker (optional): Optional. Sticker of the business intro

Summary

Types

t()

@type t() :: %ExGram.Model.BusinessIntro{
  message: String.t() | nil,
  sticker: ExGram.Model.Sticker.t() | nil,
  title: String.t() | nil
}

Functions

decode_as()