ExGram.Model.BusinessLocation (ex_gram v0.64.0)

Copy Markdown View Source

Contains information about the location of a Telegram Business account.

Check the documentation of this model on Telegram Bot API

  • address: Address of the business
  • location (optional): Optional. Location of the business

Summary

Types

t()

@type t() :: %ExGram.Model.BusinessLocation{
  address: String.t(),
  location: ExGram.Model.Location.t() | nil
}

Functions

decode_as()