ExGram.Model.BusinessOpeningHours (ex_gram v0.64.0)

Copy Markdown View Source

Describes the opening hours of a business.

Check the documentation of this model on Telegram Bot API

  • time_zone_name: Unique name of the time zone for which the opening hours are defined
  • opening_hours: List of time intervals describing business opening hours

Summary

Types

t()

@type t() :: %ExGram.Model.BusinessOpeningHours{
  opening_hours: [ExGram.Model.BusinessOpeningHoursInterval.t()],
  time_zone_name: String.t()
}

Functions

decode_as()