ExGram.Model.BusinessOpeningHoursInterval (ex_gram v0.64.0)

Copy Markdown View Source

Describes an interval of time during which a business is open.

Check the documentation of this model on Telegram Bot API

  • opening_minute: The minute's sequence number in a week, starting on Monday, marking the start of the time interval during which the business is open; 0 - 7 24 60
  • closing_minute: The minute's sequence number in a week, starting on Monday, marking the end of the time interval during which the business is open; 0 - 8 24 60

Summary

Types

t()

@type t() :: %ExGram.Model.BusinessOpeningHoursInterval{
  closing_minute: integer(),
  opening_minute: integer()
}

Functions

decode_as()