ExGram.Model.CallbackGame (ex_gram v0.64.0)

Copy Markdown View Source

A placeholder, currently holds no information. Use BotFather to set up your game.

Check the documentation of this model on Telegram Bot API

  • user_id: User identifier
  • score: New score, must be non-negative
  • force (optional): Pass True if the high score is allowed to decrease. This can be useful when fixing mistakes or banning cheaters
  • disable_edit_message (optional): Pass True if the game message should not be automatically edited to include the current scoreboard
  • chat_id (optional): Required if inline_message_id is not specified. Unique identifier for the target chat
  • message_id (optional): Required if inline_message_id is not specified. Identifier of the sent message
  • inline_message_id (optional): Required if chat_id and message_id are not specified. Identifier of the inline message

Summary

Types

t()

@type t() :: %ExGram.Model.CallbackGame{
  chat_id: integer() | nil,
  disable_edit_message: boolean() | nil,
  force: boolean() | nil,
  inline_message_id: String.t() | nil,
  message_id: integer() | nil,
  score: integer(),
  user_id: integer()
}

Functions

decode_as()