Represents the rights of an administrator in a chat.
Check the documentation of this model on Telegram Bot API
is_anonymous: True, if the user's presence in the chat is hiddencan_manage_chat: True, if the administrator can access the chat event log, get boost list, see hidden supergroup and channel members, report spam messages, ignore slow mode, and send messages to the chat without paying Telegram Stars. Implied by any other administrator privilege.can_delete_messages: True, if the administrator can delete messages of other userscan_manage_video_chats: True, if the administrator can manage video chatscan_restrict_members: True, if the administrator can restrict, ban or unban chat members, or access supergroup statisticscan_promote_members: True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that they have promoted, directly or indirectly (promoted by administrators that were appointed by the user)can_change_info: True, if the user is allowed to change the chat title, photo and other settingscan_invite_users: True, if the user is allowed to invite new users to the chatcan_post_stories: True, if the administrator can post stories to the chatcan_edit_stories: True, if the administrator can edit stories posted by other users, post stories to the chat page, pin chat stories, and access the chat's story archivecan_delete_stories: True, if the administrator can delete stories posted by other userscan_post_messages (optional): Optional. True, if the administrator can post messages in the channel, approve suggested posts, or access channel statistics; for channels onlycan_edit_messages (optional): Optional. True, if the administrator can edit messages of other users and can pin messages; for channels onlycan_pin_messages (optional): Optional. True, if the user is allowed to pin messages; for groups and supergroups onlycan_manage_topics (optional): Optional. True, if the user is allowed to create, rename, close, and reopen forum topics; for supergroups onlycan_manage_direct_messages (optional): Optional. True, if the administrator can manage direct messages of the channel and decline suggested posts; for channels onlycan_manage_tags (optional): Optional. True, if the administrator can edit the tags of regular members; for groups and supergroups only. If omitted defaults to the value of can_pin_messages.
Summary
Types
@type t() :: %ExGram.Model.ChatAdministratorRights{ can_change_info: boolean(), can_delete_messages: boolean(), can_delete_stories: boolean(), can_edit_messages: boolean() | nil, can_edit_stories: boolean(), can_invite_users: boolean(), can_manage_chat: boolean(), can_manage_direct_messages: boolean() | nil, can_manage_tags: boolean() | nil, can_manage_topics: boolean() | nil, can_manage_video_chats: boolean(), can_pin_messages: boolean() | nil, can_post_messages: boolean() | nil, can_post_stories: boolean(), can_promote_members: boolean(), can_restrict_members: boolean(), is_anonymous: boolean() }