This object represents a chat background.
Check the documentation of this model on Telegram Bot API
type: Type of the background
Summary
Types
@type t() :: %ExGram.Model.ChatBackground{type: ExGram.Model.BackgroundType.t()}
This object represents a chat background.
Check the documentation of this model on Telegram Bot API
type: Type of the background@type t() :: %ExGram.Model.ChatBackground{type: ExGram.Model.BackgroundType.t()}