ExGram.Model.ChatBoost (ex_gram v0.64.0)

Copy Markdown View Source

This object contains information about a chat boost.

Check the documentation of this model on Telegram Bot API

  • boost_id: Unique identifier of the boost
  • add_date: Point in time (Unix timestamp) when the chat was boosted
  • expiration_date: Point in time (Unix timestamp) when the boost will automatically expire, unless the booster's Telegram Premium subscription is prolonged
  • source: Source of the added boost

Summary

Types

t()

@type t() :: %ExGram.Model.ChatBoost{
  add_date: integer(),
  boost_id: String.t(),
  expiration_date: integer(),
  source: ExGram.Model.ChatBoostSource.t()
}

Functions

decode_as()