ExGram.Model.ChatBoostAdded (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about a user boosting a chat.

Check the documentation of this model on Telegram Bot API

  • boost_count: Number of boosts added by the user

Summary

Types

t()

@type t() :: %ExGram.Model.ChatBoostAdded{boost_count: integer()}

Functions

decode_as()