ExGram.Model.ChatBoostRemoved (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a boost removed from a chat.

Check the documentation of this model on Telegram Bot API

  • chat: Chat which was boosted
  • boost_id: Unique identifier of the boost
  • remove_date: Point in time (Unix timestamp) when the boost was removed
  • source: Source of the removed boost

Summary

Types

t()

@type t() :: %ExGram.Model.ChatBoostRemoved{
  boost_id: String.t(),
  chat: ExGram.Model.Chat.t(),
  remove_date: integer(),
  source: ExGram.Model.ChatBoostSource.t()
}

Functions

decode_as()