ExGram.Model.ChatBoostUpdated (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a boost added to a chat or changed.

Check the documentation of this model on Telegram Bot API

  • chat: Chat which was boosted
  • boost: Information about the chat boost

Summary

Types

t()

@type t() :: %ExGram.Model.ChatBoostUpdated{
  boost: ExGram.Model.ChatBoost.t(),
  chat: ExGram.Model.Chat.t()
}

Functions

decode_as()