ExGram.Model.ChatInviteLink (ex_gram v0.64.0)

Copy Markdown View Source

Represents an invite link for a chat.

Check the documentation of this model on Telegram Bot API

  • invite_link: The invite link. If the link was created by another chat administrator, then the second part of the link will be replaced with "…”.
  • creator: Creator of the link
  • creates_join_request: True, if users joining the chat via the link need to be approved by chat administrators
  • is_primary: True, if the link is primary
  • is_revoked: True, if the link is revoked
  • name (optional): Optional. Invite link name
  • expire_date (optional): Optional. Point in time (Unix timestamp) when the link will expire or has been expired
  • member_limit (optional): Optional. The maximum number of users that can be members of the chat simultaneously after joining the chat via this invite link; 1-99999
  • pending_join_request_count (optional): Optional. Number of pending join requests created using this link
  • subscription_period (optional): Optional. The number of seconds the subscription will be active for before the next payment
  • subscription_price (optional): Optional. The amount of Telegram Stars a user must pay initially and after each subsequent subscription period to be a member of the chat using the link

Summary

Types

t()

@type t() :: %ExGram.Model.ChatInviteLink{
  creates_join_request: boolean(),
  creator: ExGram.Model.User.t(),
  expire_date: integer() | nil,
  invite_link: String.t(),
  is_primary: boolean(),
  is_revoked: boolean(),
  member_limit: integer() | nil,
  name: String.t() | nil,
  pending_join_request_count: integer() | nil,
  subscription_period: integer() | nil,
  subscription_price: integer() | nil
}

Functions

decode_as()