ExGram.Model.ChatJoinRequest (ex_gram v0.64.0)

Copy Markdown View Source

Represents a join request sent to a chat.

Check the documentation of this model on Telegram Bot API

  • chat: Chat to which the request was sent
  • from: User that sent the join request
  • user_chat_id: Identifier of a private chat with the user who sent the join request. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot can use this identifier for 5 minutes to send messages until the join request is processed, assuming no other administrator contacted the user.
  • date: Date the request was sent in Unix time
  • bio (optional): Optional. Bio of the user.
  • invite_link (optional): Optional. Chat invite link that was used by the user to send the join request

Summary

Types

t()

@type t() :: %ExGram.Model.ChatJoinRequest{
  bio: String.t() | nil,
  chat: ExGram.Model.Chat.t(),
  date: integer(),
  from: ExGram.Model.User.t(),
  invite_link: ExGram.Model.ChatInviteLink.t() | nil,
  user_chat_id: integer()
}

Functions

decode_as()