ExGram.Model.ChatLocation (ex_gram v0.64.0)

Copy Markdown View Source

Represents a location to which a chat is connected.

Check the documentation of this model on Telegram Bot API

  • location: The location to which the supergroup is connected. Can't be a live location.
  • address: Location address; 1-64 characters, as defined by the chat owner

Summary

Types

t()

@type t() :: %ExGram.Model.ChatLocation{
  address: String.t(),
  location: ExGram.Model.Location.t()
}

Functions

decode_as()