ExGram.Model.ChatMemberBanned (ex_gram v0.64.0)

Copy Markdown View Source

Represents a chat member that was banned in the chat and can't return to the chat or view chat messages.

Check the documentation of this model on Telegram Bot API

  • status: The member's status in the chat, always "kicked”
  • user: Information about the user
  • until_date: Date when restrictions will be lifted for this user; Unix time. If 0, then the user is banned forever

Summary

Types

t()

@type t() :: %ExGram.Model.ChatMemberBanned{
  status: String.t(),
  until_date: integer(),
  user: ExGram.Model.User.t()
}

Functions

decode_as()