ExGram.Model.ChatMemberLeft (ex_gram v0.64.0)

Copy Markdown View Source

Represents a chat member that isn't currently a member of the chat, but may join it themselves.

Check the documentation of this model on Telegram Bot API

  • status: The member's status in the chat, always "left”
  • user: Information about the user

Summary

Types

t()

@type t() :: %ExGram.Model.ChatMemberLeft{
  status: String.t(),
  user: ExGram.Model.User.t()
}

Functions

decode_as()