ExGram.Model.ChatMemberMember (ex_gram v0.64.0)

Copy Markdown View Source

Represents a chat member that has no additional privileges or restrictions.

Check the documentation of this model on Telegram Bot API

  • status: The member's status in the chat, always "member”
  • user: Information about the user
  • tag (optional): Optional. Tag of the member
  • until_date (optional): Optional. Date when the user's subscription will expire; Unix time

Summary

Types

t()

@type t() :: %ExGram.Model.ChatMemberMember{
  status: String.t(),
  tag: String.t() | nil,
  until_date: integer() | nil,
  user: ExGram.Model.User.t()
}

Functions

decode_as()