ExGram.Model.ChatMemberOwner (ex_gram v0.64.0)

Copy Markdown View Source

Represents a chat member that owns the chat and has all administrator privileges.

Check the documentation of this model on Telegram Bot API

  • status: The member's status in the chat, always "creator”
  • user: Information about the user
  • is_anonymous: True, if the user's presence in the chat is hidden
  • custom_title (optional): Optional. Custom title for this user

Summary

Types

t()

@type t() :: %ExGram.Model.ChatMemberOwner{
  custom_title: String.t() | nil,
  is_anonymous: boolean(),
  status: String.t(),
  user: ExGram.Model.User.t()
}

Functions

decode_as()