ExGram.Model.ChatMemberRestricted (ex_gram v0.64.0)

Copy Markdown View Source

Represents a chat member that is under certain restrictions in the chat. Supergroups only.

Check the documentation of this model on Telegram Bot API

  • status: The member's status in the chat, always "restricted”
  • user: Information about the user
  • is_member: True, if the user is a member of the chat at the moment of the request
  • can_send_messages: True, if the user is allowed to send text messages, contacts, giveaways, giveaway winners, invoices, locations and venues
  • can_send_audios: True, if the user is allowed to send audios
  • can_send_documents: True, if the user is allowed to send documents
  • can_send_photos: True, if the user is allowed to send photos
  • can_send_videos: True, if the user is allowed to send videos
  • can_send_video_notes: True, if the user is allowed to send video notes
  • can_send_voice_notes: True, if the user is allowed to send voice notes
  • can_send_polls: True, if the user is allowed to send polls and checklists
  • can_send_other_messages: True, if the user is allowed to send animations, games, stickers and use inline bots
  • can_add_web_page_previews: True, if the user is allowed to add web page previews to their messages
  • can_edit_tag: True, if the user is allowed to edit their own tag
  • can_change_info: True, if the user is allowed to change the chat title, photo and other settings
  • can_invite_users: True, if the user is allowed to invite new users to the chat
  • can_pin_messages: True, if the user is allowed to pin messages
  • can_manage_topics: True, if the user is allowed to create forum topics
  • until_date: Date when restrictions will be lifted for this user; Unix time. If 0, then the user is restricted forever
  • tag (optional): Optional. Tag of the member

Summary

Types

t()

@type t() :: %ExGram.Model.ChatMemberRestricted{
  can_add_web_page_previews: boolean(),
  can_change_info: boolean(),
  can_edit_tag: boolean(),
  can_invite_users: boolean(),
  can_manage_topics: boolean(),
  can_pin_messages: boolean(),
  can_send_audios: boolean(),
  can_send_documents: boolean(),
  can_send_messages: boolean(),
  can_send_other_messages: boolean(),
  can_send_photos: boolean(),
  can_send_polls: boolean(),
  can_send_video_notes: boolean(),
  can_send_videos: boolean(),
  can_send_voice_notes: boolean(),
  is_member: boolean(),
  status: String.t(),
  tag: String.t() | nil,
  until_date: integer(),
  user: ExGram.Model.User.t()
}

Functions

decode_as()