ExGram.Model.ChatMemberUpdated (ex_gram v0.64.0)

Copy Markdown View Source

This object represents changes in the status of a chat member.

Check the documentation of this model on Telegram Bot API

  • chat: Chat the user belongs to
  • from: Performer of the action, which resulted in the change
  • date: Date the change was done in Unix time
  • old_chat_member: Previous information about the chat member
  • new_chat_member: New information about the chat member
  • invite_link (optional): Optional. Chat invite link, which was used by the user to join the chat; for joining by invite link events only.
  • via_join_request (optional): Optional. True, if the user joined the chat after sending a direct join request without using an invite link and being approved by an administrator
  • via_chat_folder_invite_link (optional): Optional. True, if the user joined the chat via a chat folder invite link

Summary

Types

t()

@type t() :: %ExGram.Model.ChatMemberUpdated{
  chat: ExGram.Model.Chat.t(),
  date: integer(),
  from: ExGram.Model.User.t(),
  invite_link: ExGram.Model.ChatInviteLink.t() | nil,
  new_chat_member: ExGram.Model.ChatMember.t(),
  old_chat_member: ExGram.Model.ChatMember.t(),
  via_chat_folder_invite_link: boolean() | nil,
  via_join_request: boolean() | nil
}

Functions

decode_as()