ExGram.Model.ChatOwnerChanged (ex_gram v0.64.0)

Copy Markdown View Source

Describes a service message about an ownership change in the chat.

Check the documentation of this model on Telegram Bot API

  • new_owner: The new owner of the chat

Summary

Types

t()

@type t() :: %ExGram.Model.ChatOwnerChanged{new_owner: ExGram.Model.User.t()}

Functions

decode_as()