ExGram.Model.ChatOwnerLeft (ex_gram v0.64.0)

Copy Markdown View Source

Describes a service message about the chat owner leaving the chat.

Check the documentation of this model on Telegram Bot API

  • new_owner (optional): Optional. The user which will be the new owner of the chat if the previous owner does not return to the chat

Summary

Types

t()

@type t() :: %ExGram.Model.ChatOwnerLeft{new_owner: ExGram.Model.User.t() | nil}

Functions

decode_as()