ExGram.Model.ChatPermissions (ex_gram v0.64.0)

Copy Markdown View Source

Describes actions that a non-administrator user is allowed to take in a chat.

Check the documentation of this model on Telegram Bot API

  • can_send_messages (optional): Optional. True, if the user is allowed to send text messages, contacts, giveaways, giveaway winners, invoices, locations and venues
  • can_send_audios (optional): Optional. True, if the user is allowed to send audios
  • can_send_documents (optional): Optional. True, if the user is allowed to send documents
  • can_send_photos (optional): Optional. True, if the user is allowed to send photos
  • can_send_videos (optional): Optional. True, if the user is allowed to send videos
  • can_send_video_notes (optional): Optional. True, if the user is allowed to send video notes
  • can_send_voice_notes (optional): Optional. True, if the user is allowed to send voice notes
  • can_send_polls (optional): Optional. True, if the user is allowed to send polls and checklists
  • can_send_other_messages (optional): Optional. True, if the user is allowed to send animations, games, stickers and use inline bots
  • can_add_web_page_previews (optional): Optional. True, if the user is allowed to add web page previews to their messages
  • can_edit_tag (optional): Optional. True, if the user is allowed to edit their own tag
  • can_change_info (optional): Optional. True, if the user is allowed to change the chat title, photo and other settings. Ignored in public supergroups
  • can_invite_users (optional): Optional. True, if the user is allowed to invite new users to the chat
  • can_pin_messages (optional): Optional. True, if the user is allowed to pin messages. Ignored in public supergroups
  • can_manage_topics (optional): Optional. True, if the user is allowed to create forum topics. If omitted defaults to the value of can_pin_messages

Summary

Types

t()

@type t() :: %ExGram.Model.ChatPermissions{
  can_add_web_page_previews: boolean() | nil,
  can_change_info: boolean() | nil,
  can_edit_tag: boolean() | nil,
  can_invite_users: boolean() | nil,
  can_manage_topics: boolean() | nil,
  can_pin_messages: boolean() | nil,
  can_send_audios: boolean() | nil,
  can_send_documents: boolean() | nil,
  can_send_messages: boolean() | nil,
  can_send_other_messages: boolean() | nil,
  can_send_photos: boolean() | nil,
  can_send_polls: boolean() | nil,
  can_send_video_notes: boolean() | nil,
  can_send_videos: boolean() | nil,
  can_send_voice_notes: boolean() | nil
}

Functions

decode_as()