ExGram.Model.ChatPhoto (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a chat photo.

Check the documentation of this model on Telegram Bot API

  • small_file_id: File identifier of small (160x160) chat photo. This file_id can be used only for photo download and only for as long as the photo is not changed.
  • small_file_unique_id: Unique file identifier of small (160x160) chat photo, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
  • big_file_id: File identifier of big (640x640) chat photo. This file_id can be used only for photo download and only for as long as the photo is not changed.
  • big_file_unique_id: Unique file identifier of big (640x640) chat photo, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.

Summary

Types

t()

@type t() :: %ExGram.Model.ChatPhoto{
  big_file_id: String.t(),
  big_file_unique_id: String.t(),
  small_file_id: String.t(),
  small_file_unique_id: String.t()
}

Functions

decode_as()