This object contains information about a chat that was shared with the bot using a KeyboardButtonRequestChat button.
Check the documentation of this model on Telegram Bot API
request_id: Identifier of the requestchat_id: Identifier of the shared chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the chat and could be unable to use this identifier, unless the chat is already known to the bot by some other means.title (optional): Optional. Title of the chat, if the title was requested by the bot.username (optional): Optional. Username of the chat, if the username was requested by the bot and available.photo (optional): Optional. Available sizes of the chat photo, if the photo was requested by the bot
Summary
Types
@type t() :: %ExGram.Model.ChatShared{ chat_id: integer(), photo: [ExGram.Model.PhotoSize.t()] | nil, request_id: integer(), title: String.t() | nil, username: String.t() | nil }