ExGram.Model.Checklist (ex_gram v0.64.0)

Copy Markdown View Source

Describes a checklist.

Check the documentation of this model on Telegram Bot API

  • title: Title of the checklist
  • tasks: List of tasks in the checklist
  • title_entities (optional): Optional. Special entities that appear in the checklist title
  • others_can_add_tasks (optional): Optional. True, if users other than the creator of the list can add tasks to the list
  • others_can_mark_tasks_as_done (optional): Optional. True, if users other than the creator of the list can mark tasks as done or not done

Summary

Types

t()

@type t() :: %ExGram.Model.Checklist{
  others_can_add_tasks: boolean() | nil,
  others_can_mark_tasks_as_done: boolean() | nil,
  tasks: [ExGram.Model.ChecklistTask.t()],
  title: String.t(),
  title_entities: [ExGram.Model.MessageEntity.t()] | nil
}

Functions

decode_as()