ExGram.Model.ChecklistTasksDone (ex_gram v0.64.0)

Copy Markdown View Source

Describes a service message about checklist tasks marked as done or not done.

Check the documentation of this model on Telegram Bot API

  • checklist_message (optional): Optional. Message containing the checklist whose tasks were marked as done or not done. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
  • marked_as_done_task_ids (optional): Optional. Identifiers of the tasks that were marked as done
  • marked_as_not_done_task_ids (optional): Optional. Identifiers of the tasks that were marked as not done

Summary

Types

t()

@type t() :: %ExGram.Model.ChecklistTasksDone{
  checklist_message: ExGram.Model.Message.t() | nil,
  marked_as_done_task_ids: [integer()] | nil,
  marked_as_not_done_task_ids: [integer()] | nil
}

Functions

decode_as()