ExGram.Model.Contact (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a phone contact.

Check the documentation of this model on Telegram Bot API

  • phone_number: Contact's phone number
  • first_name: Contact's first name
  • last_name (optional): Optional. Contact's last name
  • user_id (optional): Optional. Contact's user identifier in Telegram. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.
  • vcard (optional): Optional. Additional data about the contact in the form of a vCard

Summary

Types

t()

@type t() :: %ExGram.Model.Contact{
  first_name: String.t(),
  last_name: String.t() | nil,
  phone_number: String.t(),
  user_id: integer() | nil,
  vcard: String.t() | nil
}

Functions

decode_as()