ExGram.Model.CopyTextButton (ex_gram v0.64.0)

Copy Markdown View Source

This object represents an inline keyboard button that copies specified text to the clipboard.

Check the documentation of this model on Telegram Bot API

  • text: The text to be copied to the clipboard; 1-256 characters

Summary

Types

t()

@type t() :: %ExGram.Model.CopyTextButton{text: String.t()}

Functions

decode_as()