ExGram.Model.DirectMessagesTopic (ex_gram v0.64.0)

Copy Markdown View Source

Describes a topic of a direct messages chat.

Check the documentation of this model on Telegram Bot API

  • topic_id: Unique identifier of the topic. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.
  • user (optional): Optional. Information about the user that created the topic. Currently, it is always present

Summary

Types

t()

@type t() :: %ExGram.Model.DirectMessagesTopic{
  topic_id: integer(),
  user: ExGram.Model.User.t() | nil
}

Functions

decode_as()