ExGram.Model.EncryptedCredentials (ex_gram v0.64.0)

Copy Markdown View Source

Describes data required for decrypting and authenticating EncryptedPassportElement. See the Telegram Passport Documentation for a complete description of the data decryption and authentication processes.

Check the documentation of this model on Telegram Bot API

  • data: Base64-encoded encrypted JSON-serialized data with unique user's payload, data hashes and secrets required for EncryptedPassportElement decryption and authentication
  • hash: Base64-encoded data hash for data authentication
  • secret: Base64-encoded secret, encrypted with the bot's public RSA key, required for data decryption

Summary

Types

t()

@type t() :: %ExGram.Model.EncryptedCredentials{
  data: String.t(),
  hash: String.t(),
  secret: String.t()
}

Functions

decode_as()