ExGram.Model.ForumTopicCreated (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about a new forum topic created in the chat.

Check the documentation of this model on Telegram Bot API

  • name: Name of the topic
  • icon_color: Color of the topic icon in RGB format
  • icon_custom_emoji_id (optional): Optional. Unique identifier of the custom emoji shown as the topic icon
  • is_name_implicit (optional): Optional. True, if the name of the topic wasn't specified explicitly by its creator and likely needs to be changed by the bot

Summary

Types

t()

@type t() :: %ExGram.Model.ForumTopicCreated{
  icon_color: integer(),
  icon_custom_emoji_id: String.t() | nil,
  is_name_implicit: boolean() | nil,
  name: String.t()
}

Functions

decode_as()