ExGram.Model.ForumTopicEdited (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about an edited forum topic.

Check the documentation of this model on Telegram Bot API

  • name (optional): Optional. New name of the topic, if it was edited
  • icon_custom_emoji_id (optional): Optional. New identifier of the custom emoji shown as the topic icon, if it was edited; an empty string if the icon was removed

Summary

Types

t()

@type t() :: %ExGram.Model.ForumTopicEdited{
  icon_custom_emoji_id: String.t() | nil,
  name: String.t() | nil
}

Functions

decode_as()