ExGram.Model.GameHighScore (ex_gram v0.64.0)

Copy Markdown View Source

This object represents one row of the high scores table for a game.

Check the documentation of this model on Telegram Bot API

  • position: Position in high score table for the game
  • user: User
  • score: Score

Summary

Types

t()

@type t() :: %ExGram.Model.GameHighScore{
  position: integer(),
  score: integer(),
  user: ExGram.Model.User.t()
}

Functions

decode_as()