ExGram.Model.GeneralForumTopicHidden (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about General forum topic hidden in the chat. Currently holds no information.

Check the documentation of this model on Telegram Bot API

Summary

Types

t()

@type t() :: %ExGram.Model.GeneralForumTopicHidden{}

Functions

decode_as()