ExGram.Model.GiftInfo (ex_gram v0.64.0)

Copy Markdown View Source

Describes a service message about a regular gift that was sent or received.

Check the documentation of this model on Telegram Bot API

  • gift: Information about the gift
  • owned_gift_id (optional): Optional. Unique identifier of the received gift for the bot; only present for gifts received on behalf of business accounts
  • convert_star_count (optional): Optional. Number of Telegram Stars that can be claimed by the receiver by converting the gift; omitted if conversion to Telegram Stars is impossible
  • prepaid_upgrade_star_count (optional): Optional. Number of Telegram Stars that were prepaid for the ability to upgrade the gift
  • is_upgrade_separate (optional): Optional. True, if the gift's upgrade was purchased after the gift was sent
  • can_be_upgraded (optional): Optional. True, if the gift can be upgraded to a unique gift
  • text (optional): Optional. Text of the message that was added to the gift
  • entities (optional): Optional. Special entities that appear in the text
  • is_private (optional): Optional. True, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see them
  • unique_gift_number (optional): Optional. Unique number reserved for this gift when upgraded. See the number field in UniqueGift

Summary

Types

t()

@type t() :: %ExGram.Model.GiftInfo{
  can_be_upgraded: boolean() | nil,
  convert_star_count: integer() | nil,
  entities: [ExGram.Model.MessageEntity.t()] | nil,
  gift: ExGram.Model.Gift.t(),
  is_private: boolean() | nil,
  is_upgrade_separate: boolean() | nil,
  owned_gift_id: String.t() | nil,
  prepaid_upgrade_star_count: integer() | nil,
  text: String.t() | nil,
  unique_gift_number: integer() | nil
}

Functions

decode_as()