This object represent a list of gifts.
Check the documentation of this model on Telegram Bot API
gifts: The list of gifts
Summary
Types
@type t() :: %ExGram.Model.Gifts{gifts: [ExGram.Model.Gift.t()]}
This object represent a list of gifts.
Check the documentation of this model on Telegram Bot API
gifts: The list of gifts@type t() :: %ExGram.Model.Gifts{gifts: [ExGram.Model.Gift.t()]}