ExGram.Model.GiveawayCompleted (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about the completion of a giveaway without public winners.

Check the documentation of this model on Telegram Bot API

  • winner_count: Number of winners in the giveaway
  • unclaimed_prize_count (optional): Optional. Number of undistributed prizes
  • giveaway_message (optional): Optional. Message with the giveaway that was completed, if it wasn't deleted
  • is_star_giveaway (optional): Optional. True, if the giveaway is a Telegram Star giveaway. Otherwise, currently, the giveaway is a Telegram Premium giveaway.

Summary

Types

t()

@type t() :: %ExGram.Model.GiveawayCompleted{
  giveaway_message: ExGram.Model.Message.t() | nil,
  is_star_giveaway: boolean() | nil,
  unclaimed_prize_count: integer() | nil,
  winner_count: integer()
}

Functions

decode_as()