ExGram.Model.GiveawayCreated (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about the creation of a scheduled giveaway.

Check the documentation of this model on Telegram Bot API

  • prize_star_count (optional): Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only

Summary

Types

t()

@type t() :: %ExGram.Model.GiveawayCreated{prize_star_count: integer() | nil}

Functions

decode_as()