ExGram.Model.GiveawayWinners (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a message about the completion of a giveaway with public winners.

Check the documentation of this model on Telegram Bot API

  • chat: The chat that created the giveaway
  • giveaway_message_id: Identifier of the message with the giveaway in the chat
  • winners_selection_date: Point in time (Unix timestamp) when winners of the giveaway were selected
  • winner_count: Total number of winners in the giveaway
  • winners: List of up to 100 winners of the giveaway
  • additional_chat_count (optional): Optional. The number of other chats the user had to join in order to be eligible for the giveaway
  • prize_star_count (optional): Optional. The number of Telegram Stars that were split between giveaway winners; for Telegram Star giveaways only
  • premium_subscription_month_count (optional): Optional. The number of months the Telegram Premium subscription won from the giveaway will be active for; for Telegram Premium giveaways only
  • unclaimed_prize_count (optional): Optional. Number of undistributed prizes
  • only_new_members (optional): Optional. True, if only users who had joined the chats after the giveaway started were eligible to win
  • was_refunded (optional): Optional. True, if the giveaway was canceled because the payment for it was refunded
  • prize_description (optional): Optional. Description of additional giveaway prize

Summary

Types

t()

@type t() :: %ExGram.Model.GiveawayWinners{
  additional_chat_count: integer() | nil,
  chat: ExGram.Model.Chat.t(),
  giveaway_message_id: integer(),
  only_new_members: boolean() | nil,
  premium_subscription_month_count: integer() | nil,
  prize_description: String.t() | nil,
  prize_star_count: integer() | nil,
  unclaimed_prize_count: integer() | nil,
  was_refunded: boolean() | nil,
  winner_count: integer(),
  winners: [ExGram.Model.User.t()],
  winners_selection_date: integer()
}

Functions

decode_as()