ExGram.Model.InaccessibleMessage (ex_gram v0.64.0)

Copy Markdown View Source

This object describes a message that was deleted or is otherwise inaccessible to the bot.

Check the documentation of this model on Telegram Bot API

  • chat: Chat the message belonged to
  • message_id: Unique message identifier inside the chat
  • date: Always 0. The field can be used to differentiate regular and inaccessible messages.

Summary

Types

t()

@type t() :: %ExGram.Model.InaccessibleMessage{
  chat: ExGram.Model.Chat.t(),
  date: integer(),
  message_id: integer()
}

Functions

decode_as()