This object represents an incoming inline query. When the user sends an empty query, your bot could return some default or trending results.
Check the documentation of this model on Telegram Bot API
id: Unique identifier for this queryfrom: Senderquery: Text of the query (up to 256 characters)offset: Offset of the results to be returned, can be controlled by the botchat_type (optional): Optional. Type of the chat from which the inline query was sent. Can be either "sender” for a private chat with the inline query sender, "private”, "group”, "supergroup”, or "channel”. The chat type should be always known for requests sent from official clients and most third-party clients, unless the request was sent from a secret chatlocation (optional): Optional. Sender location, only for bots that request user location
Summary
Types
@type t() :: %ExGram.Model.InlineQuery{ chat_type: String.t() | nil, from: ExGram.Model.User.t(), id: String.t(), location: ExGram.Model.Location.t() | nil, offset: String.t(), query: String.t() }