ExGram.Model.InlineQueryResultArticle (ex_gram v0.64.0)

Copy Markdown View Source

Represents a link to an article or web page.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be article
  • id: Unique identifier for this result, 1-64 Bytes
  • title: Title of the result
  • input_message_content: Content of the message to be sent
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • url (optional): Optional. URL of the result
  • description (optional): Optional. Short description of the result
  • thumbnail_url (optional): Optional. Url of the thumbnail for the result
  • thumbnail_width (optional): Optional. Thumbnail width
  • thumbnail_height (optional): Optional. Thumbnail height

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultArticle{
  description: String.t() | nil,
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t(),
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  thumbnail_height: integer() | nil,
  thumbnail_url: String.t() | nil,
  thumbnail_width: integer() | nil,
  title: String.t(),
  type: String.t(),
  url: String.t() | nil
}

Functions

decode_as()