Represents a link to a file stored on the Telegram servers. By default, this file will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the file.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be documentid: Unique identifier for this result, 1-64 bytestitle: Title for the resultdocument_file_id: A valid file identifier for the filedescription (optional): Optional. Short description of the resultcaption (optional): Optional. Caption of the document to be sent, 0-1024 characters after entities parsingparse_mode (optional): Optional. Mode for parsing entities in the document caption. See formatting options for more details.caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_modereply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the file
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultCachedDocument{ caption: String.t() | nil, caption_entities: [ExGram.Model.MessageEntity.t()] | nil, description: String.t() | nil, document_file_id: String.t(), id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, parse_mode: String.t() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, title: String.t(), type: String.t() }