Represents a link to an animated GIF file stored on the Telegram servers. By default, this animated GIF file will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with specified content instead of the animation.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be gifid: Unique identifier for this result, 1-64 bytesgif_file_id: A valid file identifier for the GIF filetitle (optional): Optional. Title for the resultcaption (optional): Optional. Caption of the GIF file to be sent, 0-1024 characters after entities parsingparse_mode (optional): Optional. Mode for parsing entities in the caption. See formatting options for more details.caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_modeshow_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message mediareply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the GIF animation
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultCachedGif{ caption: String.t() | nil, caption_entities: [ExGram.Model.MessageEntity.t()] | nil, gif_file_id: String.t(), id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, parse_mode: String.t() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, show_caption_above_media: boolean() | nil, title: String.t() | nil, type: String.t() }