ExGram.Model.InlineQueryResultCachedPhoto (ex_gram v0.64.0)

Copy Markdown View Source

Represents a link to a photo stored on the Telegram servers. By default, this photo will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the photo.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be photo
  • id: Unique identifier for this result, 1-64 bytes
  • photo_file_id: A valid file identifier of the photo
  • title (optional): Optional. Title for the result
  • description (optional): Optional. Short description of the result
  • caption (optional): Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
  • parse_mode (optional): Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
  • caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
  • show_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message media
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • input_message_content (optional): Optional. Content of the message to be sent instead of the photo

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultCachedPhoto{
  caption: String.t() | nil,
  caption_entities: [ExGram.Model.MessageEntity.t()] | nil,
  description: String.t() | nil,
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t() | nil,
  parse_mode: String.t() | nil,
  photo_file_id: String.t(),
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  show_caption_above_media: boolean() | nil,
  title: String.t() | nil,
  type: String.t()
}

Functions

decode_as()