ExGram.Model.InlineQueryResultCachedSticker (ex_gram v0.64.0)

Copy Markdown View Source

Represents a link to a sticker stored on the Telegram servers. By default, this sticker will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the sticker.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be sticker
  • id: Unique identifier for this result, 1-64 bytes
  • sticker_file_id: A valid file identifier of the sticker
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • input_message_content (optional): Optional. Content of the message to be sent instead of the sticker

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultCachedSticker{
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t() | nil,
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  sticker_file_id: String.t(),
  type: String.t()
}

Functions

decode_as()