ExGram.Model.InlineQueryResultContact (ex_gram v0.64.0)

Copy Markdown View Source

Represents a contact with a phone number. By default, this contact will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the contact.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be contact
  • id: Unique identifier for this result, 1-64 Bytes
  • phone_number: Contact's phone number
  • first_name: Contact's first name
  • last_name (optional): Optional. Contact's last name
  • vcard (optional): Optional. Additional data about the contact in the form of a vCard, 0-2048 bytes
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • input_message_content (optional): Optional. Content of the message to be sent instead of the contact
  • thumbnail_url (optional): Optional. Url of the thumbnail for the result
  • thumbnail_width (optional): Optional. Thumbnail width
  • thumbnail_height (optional): Optional. Thumbnail height

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultContact{
  first_name: String.t(),
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t() | nil,
  last_name: String.t() | nil,
  phone_number: String.t(),
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  thumbnail_height: integer() | nil,
  thumbnail_url: String.t() | nil,
  thumbnail_width: integer() | nil,
  type: String.t(),
  vcard: String.t() | nil
}

Functions

decode_as()