Represents a link to a file. By default, this file will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the file. Currently, only .PDF and .ZIP files can be sent using this method.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be documentid: Unique identifier for this result, 1-64 bytestitle: Title for the resultdocument_url: A valid URL for the filemime_type: MIME type of the content of the file, either "application/pdf” or "application/zip”caption (optional): Optional. Caption of the document to be sent, 0-1024 characters after entities parsingparse_mode (optional): Optional. Mode for parsing entities in the document caption. See formatting options for more details.caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_modedescription (optional): Optional. Short description of the resultreply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the filethumbnail_url (optional): Optional. URL of the thumbnail (JPEG only) for the filethumbnail_width (optional): Optional. Thumbnail widththumbnail_height (optional): Optional. Thumbnail height
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultDocument{ caption: String.t() | nil, caption_entities: [ExGram.Model.MessageEntity.t()] | nil, description: String.t() | nil, document_url: String.t(), id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, mime_type: String.t(), parse_mode: String.t() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, thumbnail_height: integer() | nil, thumbnail_url: String.t() | nil, thumbnail_width: integer() | nil, title: String.t(), type: String.t() }