ExGram.Model.InlineQueryResultGif (ex_gram v0.64.0)

Copy Markdown View Source

Represents a link to an animated GIF file. By default, this animated GIF file will be sent by the user with optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the animation.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be gif
  • id: Unique identifier for this result, 1-64 bytes
  • gif_url: A valid URL for the GIF file
  • thumbnail_url: URL of the static (JPEG or GIF) or animated (MPEG4) thumbnail for the result
  • gif_width (optional): Optional. Width of the GIF
  • gif_height (optional): Optional. Height of the GIF
  • gif_duration (optional): Optional. Duration of the GIF in seconds
  • thumbnail_mime_type (optional): Optional. MIME type of the thumbnail, must be one of "image/jpeg”, "image/gif”, or "video/mp4”. Defaults to "image/jpeg”
  • title (optional): Optional. Title for the result
  • caption (optional): Optional. Caption of the GIF file to be sent, 0-1024 characters after entities parsing
  • parse_mode (optional): Optional. Mode for parsing entities in the caption. See formatting options for more details.
  • caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
  • show_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message media
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • input_message_content (optional): Optional. Content of the message to be sent instead of the GIF animation

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultGif{
  caption: String.t() | nil,
  caption_entities: [ExGram.Model.MessageEntity.t()] | nil,
  gif_duration: integer() | nil,
  gif_height: integer() | nil,
  gif_url: String.t(),
  gif_width: integer() | nil,
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t() | nil,
  parse_mode: String.t() | nil,
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  show_caption_above_media: boolean() | nil,
  thumbnail_mime_type: String.t() | nil,
  thumbnail_url: String.t(),
  title: String.t() | nil,
  type: String.t()
}

Functions

decode_as()