ExGram.Model.InlineQueryResultVenue (ex_gram v0.64.0)

Copy Markdown View Source

Represents a venue. By default, the venue will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the venue.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be venue
  • id: Unique identifier for this result, 1-64 Bytes
  • latitude: Latitude of the venue location in degrees
  • longitude: Longitude of the venue location in degrees
  • title: Title of the venue
  • address: Address of the venue
  • foursquare_id (optional): Optional. Foursquare identifier of the venue if known
  • foursquare_type (optional): Optional. Foursquare type of the venue, if known. (For example, "arts_entertainment/default”, "arts_entertainment/aquarium” or "food/icecream”.)
  • google_place_id (optional): Optional. Google Places identifier of the venue
  • google_place_type (optional): Optional. Google Places type of the venue. (See supported types.)
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • input_message_content (optional): Optional. Content of the message to be sent instead of the venue
  • thumbnail_url (optional): Optional. Url of the thumbnail for the result
  • thumbnail_width (optional): Optional. Thumbnail width
  • thumbnail_height (optional): Optional. Thumbnail height

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultVenue{
  address: String.t(),
  foursquare_id: String.t() | nil,
  foursquare_type: String.t() | nil,
  google_place_id: String.t() | nil,
  google_place_type: String.t() | nil,
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t() | nil,
  latitude: float(),
  longitude: float(),
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  thumbnail_height: integer() | nil,
  thumbnail_url: String.t() | nil,
  thumbnail_width: integer() | nil,
  title: String.t(),
  type: String.t()
}

Functions

decode_as()