ExGram.Model.InlineQueryResultVideo (ex_gram v0.64.0)

Copy Markdown View Source

Represents a link to a page containing an embedded video player or a video file. By default, this video file will be sent by the user with an optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the video.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be video
  • id: Unique identifier for this result, 1-64 bytes
  • video_url: A valid URL for the embedded video player or video file
  • mime_type: MIME type of the content of the video URL, "text/html” or "video/mp4”
  • thumbnail_url: URL of the thumbnail (JPEG only) for the video
  • title: Title for the result
  • caption (optional): Optional. Caption of the video to be sent, 0-1024 characters after entities parsing
  • parse_mode (optional): Optional. Mode for parsing entities in the video caption. See formatting options for more details.
  • caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
  • show_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message media
  • video_width (optional): Optional. Video width
  • video_height (optional): Optional. Video height
  • video_duration (optional): Optional. Video duration in seconds
  • description (optional): Optional. Short description of the result
  • reply_markup (optional): Optional. Inline keyboard attached to the message
  • input_message_content (optional): Optional. Content of the message to be sent instead of the video. This field is required if InlineQueryResultVideo is used to send an HTML-page as a result (e.g., a YouTube video).

Summary

Types

t()

@type t() :: %ExGram.Model.InlineQueryResultVideo{
  caption: String.t() | nil,
  caption_entities: [ExGram.Model.MessageEntity.t()] | nil,
  description: String.t() | nil,
  id: String.t(),
  input_message_content: ExGram.Model.InputMessageContent.t() | nil,
  mime_type: String.t(),
  parse_mode: String.t() | nil,
  reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil,
  show_caption_above_media: boolean() | nil,
  thumbnail_url: String.t(),
  title: String.t(),
  type: String.t(),
  video_duration: integer() | nil,
  video_height: integer() | nil,
  video_url: String.t(),
  video_width: integer() | nil
}

Functions

decode_as()