ExGram.Model.InputChecklistTask (ex_gram v0.64.0)

Copy Markdown View Source

Describes a task to add to a checklist.

Check the documentation of this model on Telegram Bot API

  • id: Unique identifier of the task; must be positive and unique among all task identifiers currently present in the checklist
  • text: Text of the task; 1-100 characters after entities parsing
  • parse_mode (optional): Optional. Mode for parsing entities in the text. See formatting options for more details.
  • text_entities (optional): Optional. List of special entities that appear in the text, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed.

Summary

Types

t()

@type t() :: %ExGram.Model.InputChecklistTask{
  id: integer(),
  parse_mode: String.t() | nil,
  text: String.t(),
  text_entities: [ExGram.Model.MessageEntity.t()] | nil
}

Functions

decode_as()