ExGram.Model.InputContactMessageContent (ex_gram v0.64.0)

Copy Markdown View Source

Represents the content of a contact message to be sent as the result of an inline query.

Check the documentation of this model on Telegram Bot API

  • phone_number: Contact's phone number
  • first_name: Contact's first name
  • last_name (optional): Optional. Contact's last name
  • vcard (optional): Optional. Additional data about the contact in the form of a vCard, 0-2048 bytes

Summary

Types

t()

@type t() :: %ExGram.Model.InputContactMessageContent{
  first_name: String.t(),
  last_name: String.t() | nil,
  phone_number: String.t(),
  vcard: String.t() | nil
}

Functions

decode_as()