ExGram.Model.InputLocationMessageContent (ex_gram v0.64.0)

Copy Markdown View Source

Represents the content of a location message to be sent as the result of an inline query.

Check the documentation of this model on Telegram Bot API

  • latitude: Latitude of the location in degrees
  • longitude: Longitude of the location in degrees
  • horizontal_accuracy (optional): Optional. The radius of uncertainty for the location, measured in meters; 0-1500
  • live_period (optional): Optional. Period in seconds during which the location can be updated, should be between 60 and 86400, or 0x7FFFFFFF for live locations that can be edited indefinitely.
  • heading (optional): Optional. For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.
  • proximity_alert_radius (optional): Optional. For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.

Summary

Types

t()

@type t() :: %ExGram.Model.InputLocationMessageContent{
  heading: integer() | nil,
  horizontal_accuracy: float() | nil,
  latitude: float(),
  live_period: integer() | nil,
  longitude: float(),
  proximity_alert_radius: integer() | nil
}

Functions

decode_as()