ExGram.Model.InputMediaPhoto (ex_gram v0.64.0)

Copy Markdown View Source

Represents a photo to be sent.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be photo
  • media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
  • caption (optional): Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
  • parse_mode (optional): Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
  • caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
  • show_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message media
  • has_spoiler (optional): Optional. Pass True if the photo needs to be covered with a spoiler animation

Summary

Types

t()

@type t() :: %ExGram.Model.InputMediaPhoto{
  caption: String.t() | nil,
  caption_entities: [ExGram.Model.MessageEntity.t()] | nil,
  has_spoiler: boolean() | nil,
  media:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  parse_mode: String.t() | nil,
  show_caption_above_media: boolean() | nil,
  type: String.t()
}

Functions

decode_as()