ExGram.Model.InputMediaVideo (ex_gram v0.64.0)

Copy Markdown View Source

Represents a video to be sent.

Check the documentation of this model on Telegram Bot API

  • type: Type of the result, must be video
  • media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
  • thumbnail (optional): Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
  • cover (optional): Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
  • start_timestamp (optional): Optional. Start timestamp for the video in the message
  • caption (optional): Optional. Caption of the video to be sent, 0-1024 characters after entities parsing
  • parse_mode (optional): Optional. Mode for parsing entities in the video caption. See formatting options for more details.
  • caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
  • show_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message media
  • width (optional): Optional. Video width
  • height (optional): Optional. Video height
  • duration (optional): Optional. Video duration in seconds
  • supports_streaming (optional): Optional. Pass True if the uploaded video is suitable for streaming
  • has_spoiler (optional): Optional. Pass True if the video needs to be covered with a spoiler animation

Summary

Types

t()

@type t() :: %ExGram.Model.InputMediaVideo{
  caption: String.t() | nil,
  caption_entities: [ExGram.Model.MessageEntity.t()] | nil,
  cover:
    (String.t()
     | {:file, String.t()}
     | {:file_content, iodata() | Enum.t(), String.t()})
    | nil,
  duration: integer() | nil,
  has_spoiler: boolean() | nil,
  height: integer() | nil,
  media:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  parse_mode: String.t() | nil,
  show_caption_above_media: boolean() | nil,
  start_timestamp: integer() | nil,
  supports_streaming: boolean() | nil,
  thumbnail:
    (String.t()
     | {:file, String.t()}
     | {:file_content, iodata() | Enum.t(), String.t()})
    | nil,
  type: String.t(),
  width: integer() | nil
}

Functions

decode_as()