ExGram.Model.InputPaidMediaPhoto (ex_gram v0.64.0)

Copy Markdown View Source

The paid media to send is a photo.

Check the documentation of this model on Telegram Bot API

  • type: Type of the media, must be photo
  • media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »

Summary

Types

t()

@type t() :: %ExGram.Model.InputPaidMediaPhoto{
  media:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  type: String.t()
}

Functions

decode_as()