ExGram.Model.InputPaidMediaVideo (ex_gram v0.64.0)

Copy Markdown View Source

The paid media to send is a video.

Check the documentation of this model on Telegram Bot API

  • type: Type of the media, must be video
  • media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
  • thumbnail (optional): Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
  • cover (optional): Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
  • start_timestamp (optional): Optional. Start timestamp for the video in the message
  • width (optional): Optional. Video width
  • height (optional): Optional. Video height
  • duration (optional): Optional. Video duration in seconds
  • supports_streaming (optional): Optional. Pass True if the uploaded video is suitable for streaming

Summary

Types

t()

@type t() :: %ExGram.Model.InputPaidMediaVideo{
  cover:
    (String.t()
     | {:file, String.t()}
     | {:file_content, iodata() | Enum.t(), String.t()})
    | nil,
  duration: integer() | nil,
  height: integer() | nil,
  media:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  start_timestamp: integer() | nil,
  supports_streaming: boolean() | nil,
  thumbnail:
    (String.t()
     | {:file, String.t()}
     | {:file_content, iodata() | Enum.t(), String.t()})
    | nil,
  type: String.t(),
  width: integer() | nil
}

Functions

decode_as()