ExGram.Model.InputPollOption (ex_gram v0.64.0)

Copy Markdown View Source

This object contains information about one answer option in a poll to be sent.

Check the documentation of this model on Telegram Bot API

  • text: Option text, 1-100 characters
  • text_parse_mode (optional): Optional. Mode for parsing entities in the text. See formatting options for more details. Currently, only custom emoji entities are allowed
  • text_entities (optional): Optional. A JSON-serialized list of special entities that appear in the poll option text. It can be specified instead of text_parse_mode

Summary

Types

t()

@type t() :: %ExGram.Model.InputPollOption{
  text: String.t(),
  text_entities: [ExGram.Model.MessageEntity.t()] | nil,
  text_parse_mode: String.t() | nil
}

Functions

decode_as()