ExGram.Model.InputProfilePhotoAnimated (ex_gram v0.64.0)

Copy Markdown View Source

An animated profile photo in the MPEG4 format.

Check the documentation of this model on Telegram Bot API

  • type: Type of the profile photo, must be animated
  • animation: The animated profile photo. Profile photos can't be reused and can only be uploaded as a new file, so you can pass "attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
  • main_frame_timestamp (optional): Optional. Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0.

Summary

Types

t()

@type t() :: %ExGram.Model.InputProfilePhotoAnimated{
  animation:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  main_frame_timestamp: float() | nil,
  type: String.t()
}

Functions

decode_as()