ExGram.Model.InputProfilePhotoStatic (ex_gram v0.64.0)

Copy Markdown View Source

A static profile photo in the .JPG format.

Check the documentation of this model on Telegram Bot API

  • type: Type of the profile photo, must be static
  • photo: The static profile photo. Profile photos can't be reused and can only be uploaded as a new file, so you can pass "attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »

Summary

Types

t()

@type t() :: %ExGram.Model.InputProfilePhotoStatic{
  photo:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  type: String.t()
}

Functions

decode_as()