ExGram.Model.InputStoryContentPhoto (ex_gram v0.64.0)

Copy Markdown View Source

Describes a photo to post as a story.

Check the documentation of this model on Telegram Bot API

  • type: Type of the content, must be photo
  • photo: The photo to post as a story. The photo must be of the size 1080x1920 and must not exceed 10 MB. The photo can't be reused and can only be uploaded as a new file, so you can pass "attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »

Summary

Types

t()

@type t() :: %ExGram.Model.InputStoryContentPhoto{
  photo:
    String.t()
    | {:file, String.t()}
    | {:file_content, iodata() | Enum.t(), String.t()},
  type: String.t()
}

Functions

decode_as()