ExGram.Model.InputTextMessageContent (ex_gram v0.64.0)

Copy Markdown View Source

Represents the content of a text message to be sent as the result of an inline query.

Check the documentation of this model on Telegram Bot API

  • message_text: Text of the message to be sent, 1-4096 characters
  • parse_mode (optional): Optional. Mode for parsing entities in the message text. See formatting options for more details.
  • entities (optional): Optional. List of special entities that appear in message text, which can be specified instead of parse_mode
  • link_preview_options (optional): Optional. Link preview generation options for the message

Summary

Types

t()

@type t() :: %ExGram.Model.InputTextMessageContent{
  entities: [ExGram.Model.MessageEntity.t()] | nil,
  link_preview_options: ExGram.Model.LinkPreviewOptions.t() | nil,
  message_text: String.t(),
  parse_mode: String.t() | nil
}

Functions

decode_as()