ExGram.Model.InputVenueMessageContent (ex_gram v0.64.0)

Copy Markdown View Source

Represents the content of a venue message to be sent as the result of an inline query.

Check the documentation of this model on Telegram Bot API

  • latitude: Latitude of the venue in degrees
  • longitude: Longitude of the venue in degrees
  • title: Name of the venue
  • address: Address of the venue
  • foursquare_id (optional): Optional. Foursquare identifier of the venue, if known
  • foursquare_type (optional): Optional. Foursquare type of the venue, if known. (For example, "arts_entertainment/default”, "arts_entertainment/aquarium” or "food/icecream”.)
  • google_place_id (optional): Optional. Google Places identifier of the venue
  • google_place_type (optional): Optional. Google Places type of the venue. (See supported types.)

Summary

Types

t()

@type t() :: %ExGram.Model.InputVenueMessageContent{
  address: String.t(),
  foursquare_id: String.t() | nil,
  foursquare_type: String.t() | nil,
  google_place_id: String.t() | nil,
  google_place_type: String.t() | nil,
  latitude: float(),
  longitude: float(),
  title: String.t()
}

Functions

decode_as()