ExGram.Model.Invoice (ex_gram v0.64.0)

Copy Markdown View Source

This object contains basic information about an invoice.

Check the documentation of this model on Telegram Bot API

  • title: Product name
  • description: Product description
  • start_parameter: Unique bot deep-linking parameter that can be used to generate this invoice
  • currency: Three-letter ISO 4217 currency code, or "XTR” for payments in Telegram Stars
  • total_amount: Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).

Summary

Types

t()

@type t() :: %ExGram.Model.Invoice{
  currency: String.t(),
  description: String.t(),
  start_parameter: String.t(),
  title: String.t(),
  total_amount: integer()
}

Functions

decode_as()