ExGram.Model.KeyboardButtonPollType (ex_gram v0.64.0)

Copy Markdown View Source

This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.

Check the documentation of this model on Telegram Bot API

  • type (optional): Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.

Summary

Types

t()

@type t() :: %ExGram.Model.KeyboardButtonPollType{type: String.t() | nil}

Functions

decode_as()