ExGram.Model.KeyboardButtonRequestUsers (ex_gram v0.64.0)

Copy Markdown View Source

This object defines the criteria used to request suitable users. Information about the selected users will be shared with the bot when the corresponding button is pressed. More about requesting users »

Check the documentation of this model on Telegram Bot API

  • request_id: Signed 32-bit identifier of the request that will be received back in the UsersShared object. Must be unique within the message
  • user_is_bot (optional): Optional. Pass True to request bots, pass False to request regular users. If not specified, no additional restrictions are applied.
  • user_is_premium (optional): Optional. Pass True to request premium users, pass False to request non-premium users. If not specified, no additional restrictions are applied.
  • max_quantity (optional): Optional. The maximum number of users to be selected; 1-10. Defaults to 1.
  • request_name (optional): Optional. Pass True to request the users' first and last names
  • request_username (optional): Optional. Pass True to request the users' usernames
  • request_photo (optional): Optional. Pass True to request the users' photos

Summary

Types

t()

@type t() :: %ExGram.Model.KeyboardButtonRequestUsers{
  max_quantity: integer() | nil,
  request_id: integer(),
  request_name: boolean() | nil,
  request_photo: boolean() | nil,
  request_username: boolean() | nil,
  user_is_bot: boolean() | nil,
  user_is_premium: boolean() | nil
}

Functions

decode_as()