ExGram.Model.LabeledPrice (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a portion of the price for goods or services.

Check the documentation of this model on Telegram Bot API

  • label: Portion label
  • amount: Price of the product in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).

Summary

Types

t()

@type t() :: %ExGram.Model.LabeledPrice{amount: integer(), label: String.t()}

Functions

decode_as()