ExGram.Model.LinkPreviewOptions (ex_gram v0.64.0)

Copy Markdown View Source

Describes the options used for link preview generation.

Check the documentation of this model on Telegram Bot API

  • is_disabled (optional): Optional. True, if the link preview is disabled
  • url (optional): Optional. URL to use for the link preview. If empty, then the first URL found in the message text will be used
  • prefer_small_media (optional): Optional. True, if the media in the link preview is supposed to be shrunk; ignored if the URL isn't explicitly specified or media size change isn't supported for the preview
  • prefer_large_media (optional): Optional. True, if the media in the link preview is supposed to be enlarged; ignored if the URL isn't explicitly specified or media size change isn't supported for the preview
  • show_above_text (optional): Optional. True, if the link preview must be shown above the message text; otherwise, the link preview will be shown below the message text

Summary

Types

t()

@type t() :: %ExGram.Model.LinkPreviewOptions{
  is_disabled: boolean() | nil,
  prefer_large_media: boolean() | nil,
  prefer_small_media: boolean() | nil,
  show_above_text: boolean() | nil,
  url: String.t() | nil
}

Functions

decode_as()