ExGram.Model.LocationAddress (ex_gram v0.65.0)

Copy Markdown View Source

Describes the physical address of a location.

Check the documentation of this model on Telegram Bot API

  • country_code: The two-letter ISO 3166-1 alpha-2 country code of the country where the location is located
  • state (optional): Optional. State of the location
  • city (optional): Optional. City of the location
  • street (optional): Optional. Street address of the location

Summary

Types

t()

@type t() :: %ExGram.Model.LocationAddress{
  city: String.t() | nil,
  country_code: String.t(),
  state: String.t() | nil,
  street: String.t() | nil
}

Functions

decode_as()