ExGram.Model.ManagedBotCreated (ex_gram v0.65.0)

Copy Markdown View Source

This object contains information about the bot that was created to be managed by the current bot.

Check the documentation of this model on Telegram Bot API

  • bot: Information about the bot. The bot's token can be fetched using the method getManagedBotToken.

Summary

Types

t()

@type t() :: %ExGram.Model.ManagedBotCreated{bot: ExGram.Model.User.t()}

Functions

decode_as()