ExGram.Model.MaskPosition (ex_gram v0.64.0)

Copy Markdown View Source

This object describes the position on faces where a mask should be placed by default.

Check the documentation of this model on Telegram Bot API

  • point: The part of the face relative to which the mask should be placed. One of "forehead”, "eyes”, "mouth”, or "chin”.
  • x_shift: Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. For example, choosing -1.0 will place mask just to the left of the default mask position.
  • y_shift: Shift by Y-axis measured in heights of the mask scaled to the face size, from top to bottom. For example, 1.0 will place the mask just below the default mask position.
  • scale: Mask scaling coefficient. For example, 2.0 means double size.

Summary

Types

t()

@type t() :: %ExGram.Model.MaskPosition{
  point: String.t(),
  scale: float(),
  x_shift: float(),
  y_shift: float()
}

Functions

decode_as()