Represents a menu button, which opens the bot's list of commands.
Check the documentation of this model on Telegram Bot API
type: Type of the button, must be commands
Summary
Types
@type t() :: %ExGram.Model.MenuButtonCommands{type: String.t()}
Represents a menu button, which opens the bot's list of commands.
Check the documentation of this model on Telegram Bot API
type: Type of the button, must be commands@type t() :: %ExGram.Model.MenuButtonCommands{type: String.t()}