ExGram.Model.MenuButtonDefault (ex_gram v0.64.0)

Copy Markdown View Source

Describes that no specific value for the menu button was set.

Check the documentation of this model on Telegram Bot API

  • type: Type of the button, must be default

Summary

Types

t()

@type t() :: %ExGram.Model.MenuButtonDefault{type: String.t()}

Functions

decode_as()