ExGram.Model.MenuButtonWebApp (ex_gram v0.64.0)

Copy Markdown View Source

Represents a menu button, which launches a Web App.

Check the documentation of this model on Telegram Bot API

  • type: Type of the button, must be web_app
  • text: Text on the button
  • web_app: Description of the Web App that will be launched when the user presses the button. The Web App will be able to send an arbitrary message on behalf of the user using the method answerWebAppQuery. Alternatively, a t.me link to a Web App of the bot can be specified in the object instead of the Web App's URL, in which case the Web App will be opened as if the user pressed the link.

Summary

Types

t()

@type t() :: %ExGram.Model.MenuButtonWebApp{
  text: String.t(),
  type: String.t(),
  web_app: ExGram.Model.WebAppInfo.t()
}

Functions

decode_as()