ExGram.Model.MessageId (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a unique message identifier.

Check the documentation of this model on Telegram Bot API

  • message_id: Unique message identifier. In specific instances (e.g., message containing a video sent to a big chat), the server might automatically schedule a message instead of sending it immediately. In such cases, this field will be 0 and the relevant message will be unusable until it is actually sent

Summary

Types

t()

@type t() :: %ExGram.Model.MessageId{message_id: integer()}

Functions

decode_as()