ExGram.Model.MessageOriginChannel (ex_gram v0.64.0)

Copy Markdown View Source

The message was originally sent to a channel chat.

Check the documentation of this model on Telegram Bot API

  • type: Type of the message origin, always "channel”
  • date: Date the message was sent originally in Unix time
  • chat: Channel chat to which the message was originally sent
  • message_id: Unique message identifier inside the chat
  • author_signature (optional): Optional. Signature of the original post author

Summary

Types

t()

@type t() :: %ExGram.Model.MessageOriginChannel{
  author_signature: String.t() | nil,
  chat: ExGram.Model.Chat.t(),
  date: integer(),
  message_id: integer(),
  type: String.t()
}

Functions

decode_as()