ExGram.Model.MessageOriginHiddenUser (ex_gram v0.64.0)

Copy Markdown View Source

The message was originally sent by an unknown user.

Check the documentation of this model on Telegram Bot API

  • type: Type of the message origin, always "hidden_user”
  • date: Date the message was sent originally in Unix time
  • sender_user_name: Name of the user that sent the message originally

Summary

Types

t()

@type t() :: %ExGram.Model.MessageOriginHiddenUser{
  date: integer(),
  sender_user_name: String.t(),
  type: String.t()
}

Functions

decode_as()