ExGram.Model.MessageOriginUser (ex_gram v0.64.0)

Copy Markdown View Source

The message was originally sent by a known user.

Check the documentation of this model on Telegram Bot API

  • type: Type of the message origin, always "user”
  • date: Date the message was sent originally in Unix time
  • sender_user: User that sent the message originally

Summary

Types

t()

@type t() :: %ExGram.Model.MessageOriginUser{
  date: integer(),
  sender_user: ExGram.Model.User.t(),
  type: String.t()
}

Functions

decode_as()