ExGram.Model.MessageReactionCountUpdated (ex_gram v0.64.0)

Copy Markdown View Source

This object represents reaction changes on a message with anonymous reactions.

Check the documentation of this model on Telegram Bot API

  • chat: The chat containing the message
  • message_id: Unique message identifier inside the chat
  • date: Date of the change in Unix time
  • reactions: List of reactions that are present on the message

Summary

Types

t()

@type t() :: %ExGram.Model.MessageReactionCountUpdated{
  chat: ExGram.Model.Chat.t(),
  date: integer(),
  message_id: integer(),
  reactions: [ExGram.Model.ReactionCount.t()]
}

Functions

decode_as()