ExGram.Model.MessageReactionUpdated (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a change of a reaction on a message performed by a user.

Check the documentation of this model on Telegram Bot API

  • chat: The chat containing the message the user reacted to
  • message_id: Unique identifier of the message inside the chat
  • date: Date of the change in Unix time
  • old_reaction: Previous list of reaction types that were set by the user
  • new_reaction: New list of reaction types that have been set by the user
  • user (optional): Optional. The user that changed the reaction, if the user isn't anonymous
  • actor_chat (optional): Optional. The chat on behalf of which the reaction was changed, if the user is anonymous

Summary

Types

t()

@type t() :: %ExGram.Model.MessageReactionUpdated{
  actor_chat: ExGram.Model.Chat.t() | nil,
  chat: ExGram.Model.Chat.t(),
  date: integer(),
  message_id: integer(),
  new_reaction: [ExGram.Model.ReactionType.t()],
  old_reaction: [ExGram.Model.ReactionType.t()],
  user: ExGram.Model.User.t() | nil
}

Functions

decode_as()