ExGram.Model.PaidMediaPreview (ex_gram v0.64.0)

Copy Markdown View Source

The paid media isn't available before the payment.

Check the documentation of this model on Telegram Bot API

  • type: Type of the paid media, always "preview”
  • width (optional): Optional. Media width as defined by the sender
  • height (optional): Optional. Media height as defined by the sender
  • duration (optional): Optional. Duration of the media in seconds as defined by the sender

Summary

Types

t()

@type t() :: %ExGram.Model.PaidMediaPreview{
  duration: integer() | nil,
  height: integer() | nil,
  type: String.t(),
  width: integer() | nil
}

Functions

decode_as()