ExGram.Model.PassportData (ex_gram v0.64.0)

Copy Markdown View Source

Describes Telegram Passport data shared with the bot by the user.

Check the documentation of this model on Telegram Bot API

  • data: Array with information about documents and other Telegram Passport elements that was shared with the bot
  • credentials: Encrypted credentials required to decrypt the data

Summary

Types

t()

@type t() :: %ExGram.Model.PassportData{
  credentials: ExGram.Model.EncryptedCredentials.t(),
  data: [ExGram.Model.EncryptedPassportElement.t()]
}

Functions

decode_as()