ExGram.Model.PassportElementErrorDataField (ex_gram v0.65.0)

Copy Markdown View Source

Represents an issue in one of the data fields that was provided by the user. The error is considered resolved when the field's value changes.

Check the documentation of this model on Telegram Bot API

  • source: Error source, must be data
  • type: The section of the user's Telegram Passport which has the error, one of "personal_details”, "passport”, "driver_license”, "identity_card”, "internal_passport”, "address”
  • field_name: Name of the data field which has the error
  • data_hash: Base64-encoded data hash
  • message: Error message

Summary

Types

t()

@type t() :: %ExGram.Model.PassportElementErrorDataField{
  data_hash: String.t(),
  field_name: String.t(),
  message: String.t(),
  source: String.t(),
  type: String.t()
}

Functions

decode_as()