ExGram.Model.PassportElementErrorFile (ex_gram v0.64.0)

Copy Markdown View Source

Represents an issue with a document scan. The error is considered resolved when the file with the document scan changes.

Check the documentation of this model on Telegram Bot API

  • source: Error source, must be file
  • type: The section of the user's Telegram Passport which has the issue, one of "utility_bill”, "bank_statement”, "rental_agreement”, "passport_registration”, "temporary_registration”
  • file_hash: Base64-encoded file hash
  • message: Error message

Summary

Types

t()

@type t() :: %ExGram.Model.PassportElementErrorFile{
  file_hash: String.t(),
  message: String.t(),
  source: String.t(),
  type: String.t()
}

Functions

decode_as()