Represents an issue with a list of scans. The error is considered resolved when the list of files containing the scans changes.
Check the documentation of this model on Telegram Bot API
source: Error source, must be filestype: The section of the user's Telegram Passport which has the issue, one of "utility_bill”, "bank_statement”, "rental_agreement”, "passport_registration”, "temporary_registration”file_hashes: List of base64-encoded file hashesmessage: Error message