ExGram.Model.PassportElementErrorTranslationFile (ex_gram v0.64.0)

Copy Markdown View Source

Represents an issue with one of the files that constitute the translation of a document. The error is considered resolved when the file changes.

Check the documentation of this model on Telegram Bot API

  • source: Error source, must be translation_file
  • type: Type of element of the user's Telegram Passport which has the issue, one of "passport”, "driver_license”, "identity_card”, "internal_passport”, "utility_bill”, "bank_statement”, "rental_agreement”, "passport_registration”, "temporary_registration”
  • file_hash: Base64-encoded file hash
  • message: Error message

Summary

Types

t()

@type t() :: %ExGram.Model.PassportElementErrorTranslationFile{
  file_hash: String.t(),
  message: String.t(),
  source: String.t(),
  type: String.t()
}

Functions

decode_as()