Represents an issue with the translated version of a document. The error is considered resolved when a file with the document translation change.
Check the documentation of this model on Telegram Bot API
source: Error source, must be translation_filestype: Type of element of the user's Telegram Passport which has the issue, one of "passport”, "driver_license”, "identity_card”, "internal_passport”, "utility_bill”, "bank_statement”, "rental_agreement”, "passport_registration”, "temporary_registration”file_hashes: List of base64-encoded file hashesmessage: Error message