ExGram.Model.PassportElementErrorUnspecified (ex_gram v0.64.0)

Copy Markdown View Source

Represents an issue in an unspecified place. The error is considered resolved when new data is added.

Check the documentation of this model on Telegram Bot API

  • source: Error source, must be unspecified
  • type: Type of element of the user's Telegram Passport which has the issue
  • element_hash: Base64-encoded element hash
  • message: Error message

Summary

Types

t()

@type t() :: %ExGram.Model.PassportElementErrorUnspecified{
  element_hash: String.t(),
  message: String.t(),
  source: String.t(),
  type: String.t()
}

Functions

decode_as()