ExGram.Model.PassportFile (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a file uploaded to Telegram Passport. Currently all Telegram Passport files are in JPEG format when decrypted and don't exceed 10MB.

Check the documentation of this model on Telegram Bot API

  • file_id: Identifier for this file, which can be used to download or reuse the file
  • file_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
  • file_size: File size in bytes
  • file_date: Unix time when the file was uploaded

Summary

Types

t()

@type t() :: %ExGram.Model.PassportFile{
  file_date: integer(),
  file_id: String.t(),
  file_size: integer(),
  file_unique_id: String.t()
}

Functions

decode_as()