ExGram.Model.PhotoSize (ex_gram v0.64.0)

Copy Markdown View Source

This object represents one size of a photo or a file / sticker thumbnail.

Check the documentation of this model on Telegram Bot API

  • file_id: Identifier for this file, which can be used to download or reuse the file
  • file_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
  • width: Photo width
  • height: Photo height
  • file_size (optional): Optional. File size in bytes

Summary

Types

t()

@type t() :: %ExGram.Model.PhotoSize{
  file_id: String.t(),
  file_size: integer() | nil,
  file_unique_id: String.t(),
  height: integer(),
  width: integer()
}

Functions

decode_as()