ExGram.Model.PollAnswer (ex_gram v0.64.0)

Copy Markdown View Source

This object represents an answer of a user in a non-anonymous poll.

Check the documentation of this model on Telegram Bot API

  • poll_id: Unique poll identifier
  • option_ids: 0-based identifiers of chosen answer options. May be empty if the vote was retracted.
  • voter_chat (optional): Optional. The chat that changed the answer to the poll, if the voter is anonymous
  • user (optional): Optional. The user that changed the answer to the poll, if the voter isn't anonymous

Summary

Types

t()

@type t() :: %ExGram.Model.PollAnswer{
  option_ids: [integer()],
  poll_id: String.t(),
  user: ExGram.Model.User.t() | nil,
  voter_chat: ExGram.Model.Chat.t() | nil
}

Functions

decode_as()