ExGram.Model.PollOption (ex_gram v0.65.0)

Copy Markdown View Source

This object contains information about one answer option in a poll.

Check the documentation of this model on Telegram Bot API

  • persistent_id: Unique identifier of the option, persistent on option addition and deletion
  • text: Option text, 1-100 characters
  • voter_count: Number of users who voted for this option; may be 0 if unknown
  • text_entities (optional): Optional. Special entities that appear in the option text. Currently, only custom emoji entities are allowed in poll option texts
  • added_by_user (optional): Optional. User who added the option; omitted if the option wasn't added by a user after poll creation
  • added_by_chat (optional): Optional. Chat that added the option; omitted if the option wasn't added by a chat after poll creation
  • addition_date (optional): Optional. Point in time (Unix timestamp) when the option was added; omitted if the option existed in the original poll

Summary

Types

t()

@type t() :: %ExGram.Model.PollOption{
  added_by_chat: ExGram.Model.Chat.t() | nil,
  added_by_user: ExGram.Model.User.t() | nil,
  addition_date: integer() | nil,
  persistent_id: String.t(),
  text: String.t(),
  text_entities: [ExGram.Model.MessageEntity.t()] | nil,
  voter_count: integer()
}

Functions

decode_as()