ExGram.Model.PollOptionAdded (ex_gram v0.65.0)

Copy Markdown View Source

Describes a service message about an option added to a poll.

Check the documentation of this model on Telegram Bot API

  • option_persistent_id: Unique identifier of the added option
  • option_text: Option text
  • poll_message (optional): Optional. Message containing the poll to which the option was added, if known. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
  • option_text_entities (optional): Optional. Special entities that appear in the option_text

Summary

Types

t()

@type t() :: %ExGram.Model.PollOptionAdded{
  option_persistent_id: String.t(),
  option_text: String.t(),
  option_text_entities: [ExGram.Model.MessageEntity.t()] | nil,
  poll_message: ExGram.Model.MaybeInaccessibleMessage.t() | nil
}

Functions

decode_as()