Describes a service message about an option deleted from a poll.
Check the documentation of this model on Telegram Bot API
option_persistent_id: Unique identifier of the deleted optionoption_text: Option textpoll_message (optional): Optional. Message containing the poll from which the option was deleted, if known. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.option_text_entities (optional): Optional. Special entities that appear in the option_text
Summary
Types
@type t() :: %ExGram.Model.PollOptionDeleted{ option_persistent_id: String.t(), option_text: String.t(), option_text_entities: [ExGram.Model.MessageEntity.t()] | nil, poll_message: ExGram.Model.MaybeInaccessibleMessage.t() | nil }