ExGram.Model.PreparedInlineMessage (ex_gram v0.64.0)

Copy Markdown View Source

Describes an inline message to be sent by a user of a Mini App.

Check the documentation of this model on Telegram Bot API

  • id: Unique identifier of the prepared message
  • expiration_date: Expiration date of the prepared message, in Unix time. Expired prepared messages can no longer be used

Summary

Types

t()

@type t() :: %ExGram.Model.PreparedInlineMessage{
  expiration_date: integer(),
  id: String.t()
}

Functions

decode_as()