ExGram.Model.PreparedKeyboardButton (ex_gram v0.65.0)

Copy Markdown View Source

Describes a keyboard button to be used by a user of a Mini App.

Check the documentation of this model on Telegram Bot API

  • id: Unique identifier of the keyboard button

Summary

Types

t()

@type t() :: %ExGram.Model.PreparedKeyboardButton{id: String.t()}

Functions

decode_as()