ExGram.Model.ProximityAlertTriggered (ex_gram v0.64.0)

Copy Markdown View Source

This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.

Check the documentation of this model on Telegram Bot API

  • traveler: User that triggered the alert
  • watcher: User that set the alert
  • distance: The distance between the users

Summary

Types

t()

@type t() :: %ExGram.Model.ProximityAlertTriggered{
  distance: integer(),
  traveler: ExGram.Model.User.t(),
  watcher: ExGram.Model.User.t()
}

Functions

decode_as()