The reaction is based on a custom emoji.
Check the documentation of this model on Telegram Bot API
type: Type of the reaction, always "custom_emoji”custom_emoji_id: Custom emoji identifier
The reaction is based on a custom emoji.
Check the documentation of this model on Telegram Bot API
type: Type of the reaction, always "custom_emoji”custom_emoji_id: Custom emoji identifier