The reaction is paid.
Check the documentation of this model on Telegram Bot API
type: Type of the reaction, always "paid”
Summary
Types
@type t() :: %ExGram.Model.ReactionTypePaid{type: String.t()}
The reaction is paid.
Check the documentation of this model on Telegram Bot API
type: Type of the reaction, always "paid”@type t() :: %ExGram.Model.ReactionTypePaid{type: String.t()}