ExGram.Model.RefundedPayment (ex_gram v0.64.0)

Copy Markdown View Source

This object contains basic information about a refunded payment.

Check the documentation of this model on Telegram Bot API

  • currency: Three-letter ISO 4217 currency code, or "XTR” for payments in Telegram Stars. Currently, always "XTR”
  • total_amount: Total refunded price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45, total_amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).
  • invoice_payload: Bot-specified invoice payload
  • telegram_payment_charge_id: Telegram payment identifier
  • provider_payment_charge_id (optional): Optional. Provider payment identifier

Summary

Types

t()

@type t() :: %ExGram.Model.RefundedPayment{
  currency: String.t(),
  invoice_payload: String.t(),
  provider_payment_charge_id: String.t() | nil,
  telegram_payment_charge_id: String.t(),
  total_amount: integer()
}

Functions

decode_as()