ExGram.Model.ResponseParameters (ex_gram v0.65.0)

Copy Markdown View Source

Describes why a request was unsuccessful.

Check the documentation of this model on Telegram Bot API

  • migrate_to_chat_id (optional): Optional. The group has been migrated to a supergroup with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
  • retry_after (optional): Optional. In case of exceeding flood control, the number of seconds left to wait before the request can be repeated

Summary

Types

t()

@type t() :: %ExGram.Model.ResponseParameters{
  migrate_to_chat_id: integer() | nil,
  retry_after: integer() | nil
}

Functions

decode_as()