The withdrawal failed and the transaction was refunded.
Check the documentation of this model on Telegram Bot API
type: Type of the state, always "failed”
Summary
Types
@type t() :: %ExGram.Model.RevenueWithdrawalStateFailed{type: String.t()}
The withdrawal failed and the transaction was refunded.
Check the documentation of this model on Telegram Bot API
type: Type of the state, always "failed”@type t() :: %ExGram.Model.RevenueWithdrawalStateFailed{type: String.t()}