The withdrawal is in progress.
Check the documentation of this model on Telegram Bot API
type: Type of the state, always "pending”
Summary
Types
@type t() :: %ExGram.Model.RevenueWithdrawalStatePending{type: String.t()}
The withdrawal is in progress.
Check the documentation of this model on Telegram Bot API
type: Type of the state, always "pending”@type t() :: %ExGram.Model.RevenueWithdrawalStatePending{type: String.t()}