ExGram.Model.RevenueWithdrawalStateSucceeded (ex_gram v0.64.0)

Copy Markdown View Source

The withdrawal succeeded.

Check the documentation of this model on Telegram Bot API

  • type: Type of the state, always "succeeded”
  • date: Date the withdrawal was completed in Unix time
  • url: An HTTPS URL that can be used to see transaction details

Summary

Types

t()

@type t() :: %ExGram.Model.RevenueWithdrawalStateSucceeded{
  date: integer(),
  type: String.t(),
  url: String.t()
}

Functions

decode_as()