ExGram.Model.SentWebAppMessage (ex_gram v0.64.0)

Copy Markdown View Source

Describes an inline message sent by a Web App on behalf of a user.

Check the documentation of this model on Telegram Bot API

  • inline_message_id (optional): Optional. Identifier of the sent inline message. Available only if there is an inline keyboard attached to the message.

Summary

Types

t()

@type t() :: %ExGram.Model.SentWebAppMessage{inline_message_id: String.t() | nil}

Functions

decode_as()