ExGram.Model.SharedUser (ex_gram v0.64.0)

Copy Markdown View Source

This object contains information about a user that was shared with the bot using a KeyboardButtonRequestUsers button.

Check the documentation of this model on Telegram Bot API

  • user_id: Identifier of the shared user. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so 64-bit integers or double-precision float types are safe for storing these identifiers. The bot may not have access to the user and could be unable to use this identifier, unless the user is already known to the bot by some other means.
  • first_name (optional): Optional. First name of the user, if the name was requested by the bot
  • last_name (optional): Optional. Last name of the user, if the name was requested by the bot
  • username (optional): Optional. Username of the user, if the username was requested by the bot
  • photo (optional): Optional. Available sizes of the chat photo, if the photo was requested by the bot

Summary

Types

t()

@type t() :: %ExGram.Model.SharedUser{
  first_name: String.t() | nil,
  last_name: String.t() | nil,
  photo: [ExGram.Model.PhotoSize.t()] | nil,
  user_id: integer(),
  username: String.t() | nil
}

Functions

decode_as()