ExGram.Model.StarAmount (ex_gram v0.64.0)

Copy Markdown View Source

Describes an amount of Telegram Stars.

Check the documentation of this model on Telegram Bot API

  • amount: Integer amount of Telegram Stars, rounded to 0; can be negative
  • nanostar_amount (optional): Optional. The number of 1/1000000000 shares of Telegram Stars; from -999999999 to 999999999; can be negative if and only if amount is non-positive

Summary

Types

t()

@type t() :: %ExGram.Model.StarAmount{
  amount: integer(),
  nanostar_amount: integer() | nil
}

Functions

decode_as()