Describes a Telegram Star transaction. Note that if the buyer initiates a chargeback with the payment provider from whom they acquired Stars (e.g., Apple, Google) following this transaction, the refunded Stars will be deducted from the bot's balance. This is outside of Telegram's control.
Check the documentation of this model on Telegram Bot API
id: Unique identifier of the transaction. Coincides with the identifier of the original transaction for refund transactions. Coincides with SuccessfulPayment.telegram_payment_charge_id for successful incoming payments from users.amount: Integer amount of Telegram Stars transferred by the transactiondate: Date the transaction was created in Unix timenanostar_amount (optional): Optional. The number of 1/1000000000 shares of Telegram Stars transferred by the transaction; from 0 to 999999999source (optional): Optional. Source of an incoming transaction (e.g., a user purchasing goods or services, Fragment refunding a failed withdrawal). Only for incoming transactionsreceiver (optional): Optional. Receiver of an outgoing transaction (e.g., a user for a purchase refund, Fragment for a withdrawal). Only for outgoing transactions
Summary
Types
@type t() :: %ExGram.Model.StarTransaction{ amount: integer(), date: integer(), id: String.t(), nanostar_amount: integer() | nil, receiver: ExGram.Model.TransactionPartner.t() | nil, source: ExGram.Model.TransactionPartner.t() | nil }