ExGram.Model.StoryAreaPosition (ex_gram v0.64.0)

Copy Markdown View Source

Describes the position of a clickable area within a story.

Check the documentation of this model on Telegram Bot API

  • x_percentage: The abscissa of the area's center, as a percentage of the media width
  • y_percentage: The ordinate of the area's center, as a percentage of the media height
  • width_percentage: The width of the area's rectangle, as a percentage of the media width
  • height_percentage: The height of the area's rectangle, as a percentage of the media height
  • rotation_angle: The clockwise rotation angle of the rectangle, in degrees; 0-360
  • corner_radius_percentage: The radius of the rectangle corner rounding, as a percentage of the media width

Summary

Types

t()

@type t() :: %ExGram.Model.StoryAreaPosition{
  corner_radius_percentage: float(),
  height_percentage: float(),
  rotation_angle: float(),
  width_percentage: float(),
  x_percentage: float(),
  y_percentage: float()
}

Functions

decode_as()