ExGram.Model.StoryAreaTypeLink (ex_gram v0.65.0)

Copy Markdown View Source

Describes a story area pointing to an HTTP or tg:// link. Currently, a story can have up to 3 link areas.

Check the documentation of this model on Telegram Bot API

  • type: Type of the area, always "link”
  • url: HTTP or tg:// URL to be opened when the area is clicked

Summary

Types

t()

@type t() :: %ExGram.Model.StoryAreaTypeLink{type: String.t(), url: String.t()}

Functions

decode_as()