ExGram.Model.StoryAreaTypeSuggestedReaction (ex_gram v0.65.0)

Copy Markdown View Source

Describes a story area pointing to a suggested reaction. Currently, a story can have up to 5 suggested reaction areas.

Check the documentation of this model on Telegram Bot API

  • type: Type of the area, always "suggested_reaction”
  • reaction_type: Type of the reaction
  • is_dark (optional): Optional. Pass True if the reaction area has a dark background
  • is_flipped (optional): Optional. Pass True if reaction area corner is flipped

Summary

Types

t()

@type t() :: %ExGram.Model.StoryAreaTypeSuggestedReaction{
  is_dark: boolean() | nil,
  is_flipped: boolean() | nil,
  reaction_type: ExGram.Model.ReactionType.t(),
  type: String.t()
}

Functions

decode_as()