ExGram.Model.StoryAreaTypeUniqueGift (ex_gram v0.65.0)

Copy Markdown View Source

Describes a story area pointing to a unique gift. Currently, a story can have at most 1 unique gift area.

Check the documentation of this model on Telegram Bot API

  • type: Type of the area, always "unique_gift”
  • name: Unique name of the gift

Summary

Types

t()

@type t() :: %ExGram.Model.StoryAreaTypeUniqueGift{name: String.t(), type: String.t()}

Functions

decode_as()