ExGram.Model.StoryAreaTypeWeather (ex_gram v0.65.0)

Copy Markdown View Source

Describes a story area containing weather information. Currently, a story can have up to 3 weather areas.

Check the documentation of this model on Telegram Bot API

  • type: Type of the area, always "weather”
  • temperature: Temperature, in degree Celsius
  • emoji: Emoji representing the weather
  • background_color: A color of the area background in the ARGB format

Summary

Types

t()

@type t() :: %ExGram.Model.StoryAreaTypeWeather{
  background_color: integer(),
  emoji: String.t(),
  temperature: float(),
  type: String.t()
}

Functions

decode_as()