ExGram.Model.SuggestedPostApprovalFailed (ex_gram v0.64.0)

Copy Markdown View Source

Describes a service message about the failed approval of a suggested post. Currently, only caused by insufficient user funds at the time of approval.

Check the documentation of this model on Telegram Bot API

  • price: Expected price of the post
  • suggested_post_message (optional): Optional. Message containing the suggested post whose approval has failed. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.

Summary

Types

t()

@type t() :: %ExGram.Model.SuggestedPostApprovalFailed{
  price: ExGram.Model.SuggestedPostPrice.t(),
  suggested_post_message: ExGram.Model.Message.t() | nil
}

Functions

decode_as()