ExGram.Model.SuggestedPostInfo (ex_gram v0.64.0)

Copy Markdown View Source

Contains information about a suggested post.

Check the documentation of this model on Telegram Bot API

  • state: State of the suggested post. Currently, it can be one of "pending”, "approved”, "declined”.
  • price (optional): Optional. Proposed price of the post. If the field is omitted, then the post is unpaid.
  • send_date (optional): Optional. Proposed send date of the post. If the field is omitted, then the post can be published at any time within 30 days at the sole discretion of the user or administrator who approves it.

Summary

Types

t()

@type t() :: %ExGram.Model.SuggestedPostInfo{
  price: ExGram.Model.SuggestedPostPrice.t() | nil,
  send_date: integer() | nil,
  state: String.t()
}

Functions

decode_as()