ExGram.Model.SuggestedPostPrice (ex_gram v0.64.0)

Copy Markdown View Source

Describes the price of a suggested post.

Check the documentation of this model on Telegram Bot API

  • currency: Currency in which the post will be paid. Currently, must be one of "XTR” for Telegram Stars or "TON” for toncoins
  • amount: The amount of the currency that will be paid for the post in the smallest units of the currency, i.e. Telegram Stars or nanotoncoins. Currently, price in Telegram Stars must be between 5 and 100000, and price in nanotoncoins must be between 10000000 and 10000000000000.

Summary

Types

t()

@type t() :: %ExGram.Model.SuggestedPostPrice{amount: integer(), currency: String.t()}

Functions

decode_as()