ExGram.Model.SwitchInlineQueryChosenChat (ex_gram v0.64.0)

Copy Markdown View Source

This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.

Check the documentation of this model on Telegram Bot API

  • query (optional): Optional. The default inline query to be inserted in the input field. If left empty, only the bot's username will be inserted
  • allow_user_chats (optional): Optional. True, if private chats with users can be chosen
  • allow_bot_chats (optional): Optional. True, if private chats with bots can be chosen
  • allow_group_chats (optional): Optional. True, if group and supergroup chats can be chosen
  • allow_channel_chats (optional): Optional. True, if channel chats can be chosen

Summary

Types

t()

@type t() :: %ExGram.Model.SwitchInlineQueryChosenChat{
  allow_bot_chats: boolean() | nil,
  allow_channel_chats: boolean() | nil,
  allow_group_chats: boolean() | nil,
  allow_user_chats: boolean() | nil,
  query: String.t() | nil
}

Functions

decode_as()