ExGram.Model.TransactionPartnerAffiliateProgram (ex_gram v0.64.0)

Copy Markdown View Source

Describes the affiliate program that issued the affiliate commission received via this transaction.

Check the documentation of this model on Telegram Bot API

  • type: Type of the transaction partner, always "affiliate_program”
  • commission_per_mille: The number of Telegram Stars received by the bot for each 1000 Telegram Stars received by the affiliate program sponsor from referred users
  • sponsor_user (optional): Optional. Information about the bot that sponsored the affiliate program

Summary

Types

t()

@type t() :: %ExGram.Model.TransactionPartnerAffiliateProgram{
  commission_per_mille: integer(),
  sponsor_user: ExGram.Model.User.t() | nil,
  type: String.t()
}

Functions

decode_as()