ExGram.Model.TransactionPartnerOther (ex_gram v0.64.0)

Copy Markdown View Source

Describes a transaction with an unknown source or recipient.

Check the documentation of this model on Telegram Bot API

  • type: Type of the transaction partner, always "other”

Summary

Types

t()

@type t() :: %ExGram.Model.TransactionPartnerOther{type: String.t()}

Functions

decode_as()