ExGram.Model.TransactionPartnerTelegramAds (ex_gram v0.64.0)

Copy Markdown View Source

Describes a withdrawal transaction to the Telegram Ads platform.

Check the documentation of this model on Telegram Bot API

  • type: Type of the transaction partner, always "telegram_ads”

Summary

Types

t()

@type t() :: %ExGram.Model.TransactionPartnerTelegramAds{type: String.t()}

Functions

decode_as()