ExGram.Model.TransactionPartnerTelegramApi (ex_gram v0.64.0)

Copy Markdown View Source

Describes a transaction with payment for paid broadcasting.

Check the documentation of this model on Telegram Bot API

  • type: Type of the transaction partner, always "telegram_api”
  • request_count: The number of successful requests that exceeded regular limits and were therefore billed

Summary

Types

t()

@type t() :: %ExGram.Model.TransactionPartnerTelegramApi{
  request_count: integer(),
  type: String.t()
}

Functions

decode_as()