ExGram.Model.UniqueGift (ex_gram v0.64.0)

Copy Markdown View Source

This object describes a unique gift that was upgraded from a regular gift.

Check the documentation of this model on Telegram Bot API

  • gift_id: Identifier of the regular gift from which the gift was upgraded
  • base_name: Human-readable name of the regular gift from which this unique gift was upgraded
  • name: Unique name of the gift. This name can be used in https://t.me/nft/... links and story areas
  • number: Unique number of the upgraded gift among gifts upgraded from the same regular gift
  • model: Model of the gift
  • symbol: Symbol of the gift
  • backdrop: Backdrop of the gift
  • is_premium (optional): Optional. True, if the original regular gift was exclusively purchaseable by Telegram Premium subscribers
  • is_burned (optional): Optional. True, if the gift was used to craft another gift and isn't available anymore
  • is_from_blockchain (optional): Optional. True, if the gift is assigned from the TON blockchain and can't be resold or transferred in Telegram
  • colors (optional): Optional. The color scheme that can be used by the gift's owner for the chat's name, replies to messages and link previews; for business account gifts and gifts that are currently on sale only
  • publisher_chat (optional): Optional. Information about the chat that published the gift

Summary

Types

t()

@type t() :: %ExGram.Model.UniqueGift{
  backdrop: ExGram.Model.UniqueGiftBackdrop.t(),
  base_name: String.t(),
  colors: ExGram.Model.UniqueGiftColors.t() | nil,
  gift_id: String.t(),
  is_burned: boolean() | nil,
  is_from_blockchain: boolean() | nil,
  is_premium: boolean() | nil,
  model: ExGram.Model.UniqueGiftModel.t(),
  name: String.t(),
  number: integer(),
  publisher_chat: ExGram.Model.Chat.t() | nil,
  symbol: ExGram.Model.UniqueGiftSymbol.t()
}

Functions

decode_as()