ExGram.Model.UniqueGiftBackdropColors (ex_gram v0.64.0)

Copy Markdown View Source

This object describes the colors of the backdrop of a unique gift.

Check the documentation of this model on Telegram Bot API

  • center_color: The color in the center of the backdrop in RGB format
  • edge_color: The color on the edges of the backdrop in RGB format
  • symbol_color: The color to be applied to the symbol in RGB format
  • text_color: The color for the text on the backdrop in RGB format

Summary

Types

t()

@type t() :: %ExGram.Model.UniqueGiftBackdropColors{
  center_color: integer(),
  edge_color: integer(),
  symbol_color: integer(),
  text_color: integer()
}

Functions

decode_as()