ExGram.Model.UniqueGiftColors (ex_gram v0.64.0)

Copy Markdown View Source

This object contains information about the color scheme for a user's name, message replies and link previews based on a unique gift.

Check the documentation of this model on Telegram Bot API

  • model_custom_emoji_id: Custom emoji identifier of the unique gift's model
  • symbol_custom_emoji_id: Custom emoji identifier of the unique gift's symbol
  • light_theme_main_color: Main color used in light themes; RGB format
  • light_theme_other_colors: List of 1-3 additional colors used in light themes; RGB format
  • dark_theme_main_color: Main color used in dark themes; RGB format
  • dark_theme_other_colors: List of 1-3 additional colors used in dark themes; RGB format

Summary

Types

t()

@type t() :: %ExGram.Model.UniqueGiftColors{
  dark_theme_main_color: integer(),
  dark_theme_other_colors: [integer()],
  light_theme_main_color: integer(),
  light_theme_other_colors: [integer()],
  model_custom_emoji_id: String.t(),
  symbol_custom_emoji_id: String.t()
}

Functions

decode_as()