ExGram.Model.UniqueGiftInfo (ex_gram v0.64.0)

Copy Markdown View Source

Describes a service message about a unique gift that was sent or received.

Check the documentation of this model on Telegram Bot API

  • gift: Information about the gift
  • origin: Origin of the gift. Currently, either "upgrade” for gifts upgraded from regular gifts, "transfer” for gifts transferred from other users or channels, "resale” for gifts bought from other users, "gifted_upgrade” for upgrades purchased after the gift was sent, or "offer” for gifts bought or sold through gift purchase offers
  • last_resale_currency (optional): Optional. For gifts bought from other users, the currency in which the payment for the gift was done. Currently, one of "XTR” for Telegram Stars or "TON” for toncoins.
  • last_resale_amount (optional): Optional. For gifts bought from other users, the price paid for the gift in either Telegram Stars or nanotoncoins
  • owned_gift_id (optional): Optional. Unique identifier of the received gift for the bot; only present for gifts received on behalf of business accounts
  • transfer_star_count (optional): Optional. Number of Telegram Stars that must be paid to transfer the gift; omitted if the bot cannot transfer the gift
  • next_transfer_date (optional): Optional. Point in time (Unix timestamp) when the gift can be transferred. If it is in the past, then the gift can be transferred now

Summary

Types

t()

@type t() :: %ExGram.Model.UniqueGiftInfo{
  gift: ExGram.Model.UniqueGift.t(),
  last_resale_amount: integer() | nil,
  last_resale_currency: String.t() | nil,
  next_transfer_date: integer() | nil,
  origin: String.t(),
  owned_gift_id: String.t() | nil,
  transfer_star_count: integer() | nil
}

Functions

decode_as()