ExGram.Model.UniqueGiftModel (ex_gram v0.64.0)

Copy Markdown View Source

This object describes the model of a unique gift.

Check the documentation of this model on Telegram Bot API

  • name: Name of the model
  • sticker: The sticker that represents the unique gift
  • rarity_per_mille: The number of unique gifts that receive this model for every 1000 gift upgrades. Always 0 for crafted gifts.
  • rarity (optional): Optional. Rarity of the model if it is a crafted model. Currently, can be "uncommon”, "rare”, "epic”, or "legendary”.

Summary

Types

t()

@type t() :: %ExGram.Model.UniqueGiftModel{
  name: String.t(),
  rarity: String.t() | nil,
  rarity_per_mille: integer(),
  sticker: ExGram.Model.Sticker.t()
}

Functions

decode_as()