ExGram.Model.UniqueGiftSymbol (ex_gram v0.64.0)

Copy Markdown View Source

This object describes the symbol shown on the pattern of a unique gift.

Check the documentation of this model on Telegram Bot API

  • name: Name of the symbol
  • sticker: The sticker that represents the unique gift
  • rarity_per_mille: The number of unique gifts that receive this model for every 1000 gifts upgraded

Summary

Types

t()

@type t() :: %ExGram.Model.UniqueGiftSymbol{
  name: String.t(),
  rarity_per_mille: integer(),
  sticker: ExGram.Model.Sticker.t()
}

Functions

decode_as()