ExGram.Model.UserChatBoosts (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a list of boosts added to a chat by a user.

Check the documentation of this model on Telegram Bot API

  • boosts: The list of boosts added to the chat by the user

Summary

Types

t()

@type t() :: %ExGram.Model.UserChatBoosts{boosts: [ExGram.Model.ChatBoost.t()]}

Functions

decode_as()