ExGram.Model.UserProfileAudios (ex_gram v0.64.0)

Copy Markdown View Source

This object represents the audios displayed on a user's profile.

Check the documentation of this model on Telegram Bot API

  • total_count: Total number of profile audios for the target user
  • audios: Requested profile audios

Summary

Types

t()

@type t() :: %ExGram.Model.UserProfileAudios{
  audios: [ExGram.Model.Audio.t()],
  total_count: integer()
}

Functions

decode_as()