ExGram.Model.UserProfilePhotos (ex_gram v0.64.0)

Copy Markdown View Source

This object represent a user's profile pictures.

Check the documentation of this model on Telegram Bot API

  • total_count: Total number of profile pictures the target user has
  • photos: Requested profile pictures (in up to 4 sizes each)

Summary

Types

t()

@type t() :: %ExGram.Model.UserProfilePhotos{
  photos: [[ExGram.Model.PhotoSize.t()]],
  total_count: integer()
}

Functions

decode_as()