ExGram.Model.UsersShared (ex_gram v0.64.0)

Copy Markdown View Source

This object contains information about the users whose identifiers were shared with the bot using a KeyboardButtonRequestUsers button.

Check the documentation of this model on Telegram Bot API

  • request_id: Identifier of the request
  • users: Information about users shared with the bot.

Summary

Types

t()

@type t() :: %ExGram.Model.UsersShared{
  request_id: integer(),
  users: [ExGram.Model.SharedUser.t()]
}

Functions

decode_as()