ExGram.Model.VideoChatParticipantsInvited (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about new members invited to a video chat.

Check the documentation of this model on Telegram Bot API

  • users: New members that were invited to the video chat

Summary

Types

t()

@type t() :: %ExGram.Model.VideoChatParticipantsInvited{
  users: [ExGram.Model.User.t()]
}

Functions

decode_as()