ExGram.Model.VideoChatScheduled (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about a video chat scheduled in the chat.

Check the documentation of this model on Telegram Bot API

  • start_date: Point in time (Unix timestamp) when the video chat is supposed to be started by a chat administrator

Summary

Types

t()

@type t() :: %ExGram.Model.VideoChatScheduled{start_date: integer()}

Functions

decode_as()