ExGram.Model.VideoNote (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a video message (available in Telegram apps as of v.4.0).

Check the documentation of this model on Telegram Bot API

  • file_id: Identifier for this file, which can be used to download or reuse the file
  • file_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
  • length: Video width and height (diameter of the video message) as defined by the sender
  • duration: Duration of the video in seconds as defined by the sender
  • thumbnail (optional): Optional. Video thumbnail
  • file_size (optional): Optional. File size in bytes

Summary

Types

t()

@type t() :: %ExGram.Model.VideoNote{
  duration: integer(),
  file_id: String.t(),
  file_size: integer() | nil,
  file_unique_id: String.t(),
  length: integer(),
  thumbnail: ExGram.Model.PhotoSize.t() | nil
}

Functions

decode_as()