ExGram.Model.WebAppInfo (ex_gram v0.64.0)

Copy Markdown View Source

Describes a Web App.

Check the documentation of this model on Telegram Bot API

  • url: An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps

Summary

Types

t()

@type t() :: %ExGram.Model.WebAppInfo{url: String.t()}

Functions

decode_as()