ExGram.Model.WriteAccessAllowed (ex_gram v0.64.0)

Copy Markdown View Source

This object represents a service message about a user allowing a bot to write messages after adding it to the attachment menu, launching a Web App from a link, or accepting an explicit request from a Web App sent by the method requestWriteAccess.

Check the documentation of this model on Telegram Bot API

  • from_request (optional): Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess
  • web_app_name (optional): Optional. Name of the Web App, if the access was granted when the Web App was launched from a link
  • from_attachment_menu (optional): Optional. True, if the access was granted when the bot was added to the attachment or side menu

Summary

Types

t()

@type t() :: %ExGram.Model.WriteAccessAllowed{
  from_attachment_menu: boolean() | nil,
  from_request: boolean() | nil,
  web_app_name: String.t() | nil
}

Functions

decode_as()