ExGram.Plug (ex_gram v0.64.0)

Copy Markdown View Source

A Plug to handle incoming Telegram updates in webhook mode. It checks for the secret token (if configured) and processes the update accordingly.

This plug is used with ExGram.Updates.Webhook to receive updates from Telegram. See the Polling and Webhooks guide for setup instructions.