Simple text answer response using ExGram.send_message/3.
This is a helper response type used by ExGram.Dsl to send text messages as
command handler responses.
Simple text answer response using ExGram.send_message/3.
This is a helper response type used by ExGram.Dsl to send text messages as
command handler responses.