Edit markup response using ExGram.edit_message_reply_markup/1.
This response type edits the reply markup (inline keyboard) of either a regular message or an inline message. It automatically detects which type based on the provided message identifiers.
Used by ExGram.Dsl for editing keyboard responses.