Dynamically compiles the ExGram.Encoder.Engine module with the selected engine.
This allows the engine backend to be defined at compile time without reading from application config on every call.
Dynamically compiles the ExGram.Encoder.Engine module with the selected engine.
This allows the engine backend to be defined at compile time without reading from application config on every call.