Helpers for the ExGram.Macros module
Summary
Functions
Entry point for all the macros that has parameters (model + method).
Functions
Entry point for all the macros that has parameters (model + method).
It analyzed the AST and return the list of params with the following format:
- For mandatory parameters:
[name, types, description] - For optional parameters:
[name, types, description, :optional]
All the other methods in this module that deal with parameters expect this format.