This object describes the types of gifts that can be gifted to a user or a chat.
Check the documentation of this model on Telegram Bot API
unlimited_gifts: True, if unlimited regular gifts are acceptedlimited_gifts: True, if limited regular gifts are acceptedunique_gifts: True, if unique gifts or gifts that can be upgraded to unique for free are acceptedpremium_subscription: True, if a Telegram Premium subscription is acceptedgifts_from_channels: True, if transfers of unique gifts from channels are accepted