This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).
Check the documentation of this model on Telegram Bot API
file_id: Identifier for this file, which can be used to download or reuse the filefile_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.width: Video width as defined by the senderheight: Video height as defined by the senderduration: Duration of the video in seconds as defined by the senderthumbnail (optional): Optional. Animation thumbnail as defined by the senderfile_name (optional): Optional. Original animation filename as defined by the sendermime_type (optional): Optional. MIME type of the file as defined by the senderfile_size (optional): Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.