The background is a freeform gradient that rotates after every message in the chat.
Check the documentation of this model on Telegram Bot API
type: Type of the background fill, always "freeform_gradient”colors: A list of the 3 or 4 base colors that are used to generate the freeform gradient in the RGB24 format