The background is a gradient fill.
Check the documentation of this model on Telegram Bot API
type: Type of the background fill, always "gradient”top_color: Top color of the gradient in the RGB24 formatbottom_color: Bottom color of the gradient in the RGB24 formatrotation_angle: Clockwise rotation angle of the background fill in degrees; 0-359