The background is filled using the selected color.
Check the documentation of this model on Telegram Bot API
type: Type of the background fill, always "solid”color: The color of the background fill in the RGB24 format
The background is filled using the selected color.
Check the documentation of this model on Telegram Bot API
type: Type of the background fill, always "solid”color: The color of the background fill in the RGB24 format