The background is taken directly from a built-in chat theme.
Check the documentation of this model on Telegram Bot API
type: Type of the background, always "chat_theme”theme_name: Name of the chat theme, which is usually an emoji
The background is taken directly from a built-in chat theme.
Check the documentation of this model on Telegram Bot API
type: Type of the background, always "chat_theme”theme_name: Name of the chat theme, which is usually an emoji