The background is automatically filled based on the selected colors.
Check the documentation of this model on Telegram Bot API
type: Type of the background, always "fill”fill: The background filldark_theme_dimming: Dimming of the background in dark themes, as a percentage; 0-100
Summary
Types
@type t() :: %ExGram.Model.BackgroundTypeFill{ dark_theme_dimming: integer(), fill: ExGram.Model.BackgroundFill.t(), type: String.t() }