This object represents a bot command.
Check the documentation of this model on Telegram Bot API
command: Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and underscores.description: Description of the command; 1-256 characters.