Represents the scope of bot commands, covering all group and supergroup chats.
Check the documentation of this model on Telegram Bot API
type: Scope type, must be all_group_chats
Summary
Types
@type t() :: %ExGram.Model.BotCommandScopeAllGroupChats{type: String.t()}