Represents the scope of bot commands, covering all private chats.
Check the documentation of this model on Telegram Bot API
type: Scope type, must be all_private_chats
Summary
Types
@type t() :: %ExGram.Model.BotCommandScopeAllPrivateChats{type: String.t()}