Represents the scope of bot commands, covering all administrators of a specific group or supergroup chat.
Check the documentation of this model on Telegram Bot API
type: Scope type, must be chat_administratorschat_id: Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername). Channel direct messages chats and channel chats aren't supported.