Represents the default scope of bot commands. Default commands are used if no commands with a narrower scope are specified for the user.
Check the documentation of this model on Telegram Bot API
type: Scope type, must be default
Summary
Types
@type t() :: %ExGram.Model.BotCommandScopeDefault{type: String.t()}