Describes the connection of the bot with a business account.
Check the documentation of this model on Telegram Bot API
id: Unique identifier of the business connectionuser: Business account user that created the business connectionuser_chat_id: Identifier of a private chat with the user who created the business connection. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.date: Date the connection was established in Unix timeis_enabled: True, if the connection is activerights (optional): Optional. Rights of the business bot
Summary
Types
@type t() :: %ExGram.Model.BusinessConnection{ date: integer(), id: String.t(), is_enabled: boolean(), rights: ExGram.Model.BusinessBotRights.t() | nil, user: ExGram.Model.User.t(), user_chat_id: integer() }