Contains information about the start page settings of a Telegram Business account.
Check the documentation of this model on Telegram Bot API
title (optional): Optional. Title text of the business intromessage (optional): Optional. Message text of the business introsticker (optional): Optional. Sticker of the business intro
Summary
Types
@type t() :: %ExGram.Model.BusinessIntro{ message: String.t() | nil, sticker: ExGram.Model.Sticker.t() | nil, title: String.t() | nil }