Contains information about the location of a Telegram Business account.
Check the documentation of this model on Telegram Bot API
address: Address of the businesslocation (optional): Optional. Location of the business
Summary
Types
@type t() :: %ExGram.Model.BusinessLocation{ address: String.t(), location: ExGram.Model.Location.t() | nil }