This object is received when messages are deleted from a connected business account.
Check the documentation of this model on Telegram Bot API
business_connection_id: Unique identifier of the business connectionchat: Information about a chat in the business account. The bot may not have access to the chat or the corresponding user.message_ids: The list of identifiers of deleted messages in the chat of the business account
Summary
Types
@type t() :: %ExGram.Model.BusinessMessagesDeleted{ business_connection_id: String.t(), chat: ExGram.Model.Chat.t(), message_ids: [integer()] }