Describes the opening hours of a business.
Check the documentation of this model on Telegram Bot API
time_zone_name: Unique name of the time zone for which the opening hours are definedopening_hours: List of time intervals describing business opening hours
Summary
Types
@type t() :: %ExGram.Model.BusinessOpeningHours{ opening_hours: [ExGram.Model.BusinessOpeningHoursInterval.t()], time_zone_name: String.t() }