A placeholder, currently holds no information. Use BotFather to set up your game.
Check the documentation of this model on Telegram Bot API
user_id: User identifierscore: New score, must be non-negativeforce (optional): Pass True if the high score is allowed to decrease. This can be useful when fixing mistakes or banning cheatersdisable_edit_message (optional): Pass True if the game message should not be automatically edited to include the current scoreboardchat_id (optional): Required if inline_message_id is not specified. Unique identifier for the target chatmessage_id (optional): Required if inline_message_id is not specified. Identifier of the sent messageinline_message_id (optional): Required if chat_id and message_id are not specified. Identifier of the inline message