This object represents a chat.
Check the documentation of this model on Telegram Bot API
id: Unique identifier for this chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.type: Type of the chat, can be either "private”, "group”, "supergroup” or "channel”title (optional): Optional. Title, for supergroups, channels and group chatsusername (optional): Optional. Username, for private chats, supergroups and channels if availablefirst_name (optional): Optional. First name of the other party in a private chatlast_name (optional): Optional. Last name of the other party in a private chatis_forum (optional): Optional. True, if the supergroup chat is a forum (has topics enabled)is_direct_messages (optional): Optional. True, if the chat is the direct messages chat of a channel