This object contains information about a chat boost.
Check the documentation of this model on Telegram Bot API
boost_id: Unique identifier of the boostadd_date: Point in time (Unix timestamp) when the chat was boostedexpiration_date: Point in time (Unix timestamp) when the boost will automatically expire, unless the booster's Telegram Premium subscription is prolongedsource: Source of the added boost
Summary
Types
@type t() :: %ExGram.Model.ChatBoost{ add_date: integer(), boost_id: String.t(), expiration_date: integer(), source: ExGram.Model.ChatBoostSource.t() }