This object represents a service message about a user boosting a chat.
Check the documentation of this model on Telegram Bot API
boost_count: Number of boosts added by the user
Summary
Types
@type t() :: %ExGram.Model.ChatBoostAdded{boost_count: integer()}