This object represents a boost removed from a chat.
Check the documentation of this model on Telegram Bot API
chat: Chat which was boostedboost_id: Unique identifier of the boostremove_date: Point in time (Unix timestamp) when the boost was removedsource: Source of the removed boost
Summary
Types
@type t() :: %ExGram.Model.ChatBoostRemoved{ boost_id: String.t(), chat: ExGram.Model.Chat.t(), remove_date: integer(), source: ExGram.Model.ChatBoostSource.t() }