The boost was obtained by the creation of Telegram Premium gift codes to boost a chat. Each such code boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription.
Check the documentation of this model on Telegram Bot API
source: Source of the boost, always "gift_code”user: User for which the gift code was created
Summary
Types
@type t() :: %ExGram.Model.ChatBoostSourceGiftCode{ source: String.t(), user: ExGram.Model.User.t() }