The boost was obtained by the creation of a Telegram Premium or a Telegram Star giveaway. This boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription for Telegram Premium giveaways and prize_star_count / 500 times for one year for Telegram Star giveaways.
Check the documentation of this model on Telegram Bot API
source: Source of the boost, always "giveaway”giveaway_message_id: Identifier of a message in the chat with the giveaway; the message could have been deleted already. May be 0 if the message isn't sent yet.user (optional): Optional. User that won the prize in the giveaway if any; for Telegram Premium giveaways onlyprize_star_count (optional): Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways onlyis_unclaimed (optional): Optional. True, if the giveaway was completed, but there was no user to win the prize
Summary
Types
@type t() :: %ExGram.Model.ChatBoostSourceGiveaway{ giveaway_message_id: integer(), is_unclaimed: boolean() | nil, prize_star_count: integer() | nil, source: String.t(), user: ExGram.Model.User.t() | nil }