The boost was obtained by subscribing to Telegram Premium or by gifting a Telegram Premium subscription to another user.
Check the documentation of this model on Telegram Bot API
source: Source of the boost, always "premium”user: User that boosted the chat
Summary
Types
@type t() :: %ExGram.Model.ChatBoostSourcePremium{ source: String.t(), user: ExGram.Model.User.t() }