This object represents a boost added to a chat or changed.
Check the documentation of this model on Telegram Bot API
chat: Chat which was boostedboost: Information about the chat boost
Summary
Types
@type t() :: %ExGram.Model.ChatBoostUpdated{ boost: ExGram.Model.ChatBoost.t(), chat: ExGram.Model.Chat.t() }