Represents a location to which a chat is connected.
Check the documentation of this model on Telegram Bot API
location: The location to which the supergroup is connected. Can't be a live location.address: Location address; 1-64 characters, as defined by the chat owner
Summary
Types
@type t() :: %ExGram.Model.ChatLocation{ address: String.t(), location: ExGram.Model.Location.t() }