Represents a chat member that owns the chat and has all administrator privileges.
Check the documentation of this model on Telegram Bot API
status: The member's status in the chat, always "creator”user: Information about the useris_anonymous: True, if the user's presence in the chat is hiddencustom_title (optional): Optional. Custom title for this user
Summary
Types
@type t() :: %ExGram.Model.ChatMemberOwner{ custom_title: String.t() | nil, is_anonymous: boolean(), status: String.t(), user: ExGram.Model.User.t() }