Represents a chat member that is under certain restrictions in the chat. Supergroups only.
Check the documentation of this model on Telegram Bot API
status: The member's status in the chat, always "restricted”user: Information about the useris_member: True, if the user is a member of the chat at the moment of the requestcan_send_messages: True, if the user is allowed to send text messages, contacts, giveaways, giveaway winners, invoices, locations and venuescan_send_audios: True, if the user is allowed to send audioscan_send_documents: True, if the user is allowed to send documentscan_send_photos: True, if the user is allowed to send photoscan_send_videos: True, if the user is allowed to send videoscan_send_video_notes: True, if the user is allowed to send video notescan_send_voice_notes: True, if the user is allowed to send voice notescan_send_polls: True, if the user is allowed to send polls and checklistscan_send_other_messages: True, if the user is allowed to send animations, games, stickers and use inline botscan_add_web_page_previews: True, if the user is allowed to add web page previews to their messagescan_edit_tag: True, if the user is allowed to edit their own tagcan_change_info: True, if the user is allowed to change the chat title, photo and other settingscan_invite_users: True, if the user is allowed to invite new users to the chatcan_pin_messages: True, if the user is allowed to pin messagescan_manage_topics: True, if the user is allowed to create forum topicsuntil_date: Date when restrictions will be lifted for this user; Unix time. If 0, then the user is restricted forevertag (optional): Optional. Tag of the member
Summary
Types
@type t() :: %ExGram.Model.ChatMemberRestricted{ can_add_web_page_previews: boolean(), can_change_info: boolean(), can_edit_tag: boolean(), can_invite_users: boolean(), can_manage_topics: boolean(), can_pin_messages: boolean(), can_send_audios: boolean(), can_send_documents: boolean(), can_send_messages: boolean(), can_send_other_messages: boolean(), can_send_photos: boolean(), can_send_polls: boolean(), can_send_video_notes: boolean(), can_send_videos: boolean(), can_send_voice_notes: boolean(), is_member: boolean(), status: String.t(), tag: String.t() | nil, until_date: integer(), user: ExGram.Model.User.t() }