Describes actions that a non-administrator user is allowed to take in a chat.
Check the documentation of this model on Telegram Bot API
can_send_messages (optional): Optional. True, if the user is allowed to send text messages, contacts, giveaways, giveaway winners, invoices, locations and venuescan_send_audios (optional): Optional. True, if the user is allowed to send audioscan_send_documents (optional): Optional. True, if the user is allowed to send documentscan_send_photos (optional): Optional. True, if the user is allowed to send photoscan_send_videos (optional): Optional. True, if the user is allowed to send videoscan_send_video_notes (optional): Optional. True, if the user is allowed to send video notescan_send_voice_notes (optional): Optional. True, if the user is allowed to send voice notescan_send_polls (optional): Optional. True, if the user is allowed to send polls and checklistscan_send_other_messages (optional): Optional. True, if the user is allowed to send animations, games, stickers and use inline botscan_add_web_page_previews (optional): Optional. True, if the user is allowed to add web page previews to their messagescan_edit_tag (optional): Optional. True, if the user is allowed to edit their own tagcan_change_info (optional): Optional. True, if the user is allowed to change the chat title, photo and other settings. Ignored in public supergroupscan_invite_users (optional): Optional. True, if the user is allowed to invite new users to the chatcan_pin_messages (optional): Optional. True, if the user is allowed to pin messages. Ignored in public supergroupscan_manage_topics (optional): Optional. True, if the user is allowed to create forum topics. If omitted defaults to the value of can_pin_messages
Summary
Types
@type t() :: %ExGram.Model.ChatPermissions{ can_add_web_page_previews: boolean() | nil, can_change_info: boolean() | nil, can_edit_tag: boolean() | nil, can_invite_users: boolean() | nil, can_manage_topics: boolean() | nil, can_pin_messages: boolean() | nil, can_send_audios: boolean() | nil, can_send_documents: boolean() | nil, can_send_messages: boolean() | nil, can_send_other_messages: boolean() | nil, can_send_photos: boolean() | nil, can_send_polls: boolean() | nil, can_send_video_notes: boolean() | nil, can_send_videos: boolean() | nil, can_send_voice_notes: boolean() | nil }