Describes a checklist.
Check the documentation of this model on Telegram Bot API
title: Title of the checklisttasks: List of tasks in the checklisttitle_entities (optional): Optional. Special entities that appear in the checklist titleothers_can_add_tasks (optional): Optional. True, if users other than the creator of the list can add tasks to the listothers_can_mark_tasks_as_done (optional): Optional. True, if users other than the creator of the list can mark tasks as done or not done
Summary
Types
@type t() :: %ExGram.Model.Checklist{ others_can_add_tasks: boolean() | nil, others_can_mark_tasks_as_done: boolean() | nil, tasks: [ExGram.Model.ChecklistTask.t()], title: String.t(), title_entities: [ExGram.Model.MessageEntity.t()] | nil }