Describes a service message about tasks added to a checklist.
Check the documentation of this model on Telegram Bot API
tasks: List of tasks added to the checklistchecklist_message (optional): Optional. Message containing the checklist to which the tasks were added. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Summary
Types
@type t() :: %ExGram.Model.ChecklistTasksAdded{ checklist_message: ExGram.Model.Message.t() | nil, tasks: [ExGram.Model.ChecklistTask.t()] }