Represents a result of an inline query that was chosen by the user and sent to their chat partner.
Check the documentation of this model on Telegram Bot API
result_id: The unique identifier for the result that was chosenfrom: The user that chose the resultquery: The query that was used to obtain the resultlocation (optional): Optional. Sender location, only for bots that require user locationinline_message_id (optional): Optional. Identifier of the sent inline message. Available only if there is an inline keyboard attached to the message. Will be also received in callback queries and can be used to edit the message.
Summary
Types
@type t() :: %ExGram.Model.ChosenInlineResult{ from: ExGram.Model.User.t(), inline_message_id: String.t() | nil, location: ExGram.Model.Location.t() | nil, query: String.t(), result_id: String.t() }