This object represents a phone contact.
Check the documentation of this model on Telegram Bot API
phone_number: Contact's phone numberfirst_name: Contact's first namelast_name (optional): Optional. Contact's last nameuser_id (optional): Optional. Contact's user identifier in Telegram. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.vcard (optional): Optional. Additional data about the contact in the form of a vCard