This object represents an animated emoji that displays a random value.
Check the documentation of this model on Telegram Bot API
emoji: Emoji on which the dice throw animation is basedvalue: Value of the dice, 1-6 for "”, "” and "” base emoji, 1-5 for "” and "” base emoji, 1-64 for "” base emoji