Describes a service message about a change in the price of direct messages sent to a channel chat.
Check the documentation of this model on Telegram Bot API
are_direct_messages_enabled: True, if direct messages are enabled for the channel chat; false otherwisedirect_message_star_count (optional): Optional. The new number of Telegram Stars that must be paid by users for each direct message sent to the channel. Does not apply to users who have been exempted by administrators. Defaults to 0.