This object represents a service message about a new forum topic created in the chat.
Check the documentation of this model on Telegram Bot API
name: Name of the topicicon_color: Color of the topic icon in RGB formaticon_custom_emoji_id (optional): Optional. Unique identifier of the custom emoji shown as the topic iconis_name_implicit (optional): Optional. True, if the name of the topic wasn't specified explicitly by its creator and likely needs to be changed by the bot