This object represents one row of the high scores table for a game.
Check the documentation of this model on Telegram Bot API
position: Position in high score table for the gameuser: Userscore: Score
Summary
Types
@type t() :: %ExGram.Model.GameHighScore{ position: integer(), score: integer(), user: ExGram.Model.User.t() }