This object represents a service message about General forum topic unhidden in the chat. Currently holds no information.
Check the documentation of this model on Telegram Bot API
@type t() :: %ExGram.Model.GeneralForumTopicUnhidden{}