This object represents a gift that can be sent by the bot.
Check the documentation of this model on Telegram Bot API
id: Unique identifier of the giftsticker: The sticker that represents the giftstar_count: The number of Telegram Stars that must be paid to send the stickerupgrade_star_count (optional): Optional. The number of Telegram Stars that must be paid to upgrade the gift to a unique oneis_premium (optional): Optional. True, if the gift can only be purchased by Telegram Premium subscribershas_colors (optional): Optional. True, if the gift can be used (after being upgraded) to customize a user's appearancetotal_count (optional): Optional. The total number of gifts of this type that can be sent by all users; for limited gifts onlyremaining_count (optional): Optional. The number of remaining gifts of this type that can be sent by all users; for limited gifts onlypersonal_total_count (optional): Optional. The total number of gifts of this type that can be sent by the bot; for limited gifts onlypersonal_remaining_count (optional): Optional. The number of remaining gifts of this type that can be sent by the bot; for limited gifts onlybackground (optional): Optional. Background of the giftunique_gift_variant_count (optional): Optional. The total number of different unique gifts that can be obtained by upgrading the giftpublisher_chat (optional): Optional. Information about the chat that published the gift
Summary
Types
@type t() :: %ExGram.Model.Gift{ background: ExGram.Model.GiftBackground.t() | nil, has_colors: boolean() | nil, id: String.t(), is_premium: boolean() | nil, personal_remaining_count: integer() | nil, personal_total_count: integer() | nil, publisher_chat: ExGram.Model.Chat.t() | nil, remaining_count: integer() | nil, star_count: integer(), sticker: ExGram.Model.Sticker.t(), total_count: integer() | nil, unique_gift_variant_count: integer() | nil, upgrade_star_count: integer() | nil }