Describes a service message about a regular gift that was sent or received.
Check the documentation of this model on Telegram Bot API
gift: Information about the giftowned_gift_id (optional): Optional. Unique identifier of the received gift for the bot; only present for gifts received on behalf of business accountsconvert_star_count (optional): Optional. Number of Telegram Stars that can be claimed by the receiver by converting the gift; omitted if conversion to Telegram Stars is impossibleprepaid_upgrade_star_count (optional): Optional. Number of Telegram Stars that were prepaid for the ability to upgrade the giftis_upgrade_separate (optional): Optional. True, if the gift's upgrade was purchased after the gift was sentcan_be_upgraded (optional): Optional. True, if the gift can be upgraded to a unique gifttext (optional): Optional. Text of the message that was added to the giftentities (optional): Optional. Special entities that appear in the textis_private (optional): Optional. True, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see themunique_gift_number (optional): Optional. Unique number reserved for this gift when upgraded. See the number field in UniqueGift
Summary
Types
@type t() :: %ExGram.Model.GiftInfo{ can_be_upgraded: boolean() | nil, convert_star_count: integer() | nil, entities: [ExGram.Model.MessageEntity.t()] | nil, gift: ExGram.Model.Gift.t(), is_private: boolean() | nil, is_upgrade_separate: boolean() | nil, owned_gift_id: String.t() | nil, prepaid_upgrade_star_count: integer() | nil, text: String.t() | nil, unique_gift_number: integer() | nil }