This object represents a message about the completion of a giveaway with public winners.
Check the documentation of this model on Telegram Bot API
chat: The chat that created the giveawaygiveaway_message_id: Identifier of the message with the giveaway in the chatwinners_selection_date: Point in time (Unix timestamp) when winners of the giveaway were selectedwinner_count: Total number of winners in the giveawaywinners: List of up to 100 winners of the giveawayadditional_chat_count (optional): Optional. The number of other chats the user had to join in order to be eligible for the giveawayprize_star_count (optional): Optional. The number of Telegram Stars that were split between giveaway winners; for Telegram Star giveaways onlypremium_subscription_month_count (optional): Optional. The number of months the Telegram Premium subscription won from the giveaway will be active for; for Telegram Premium giveaways onlyunclaimed_prize_count (optional): Optional. Number of undistributed prizesonly_new_members (optional): Optional. True, if only users who had joined the chats after the giveaway started were eligible to winwas_refunded (optional): Optional. True, if the giveaway was canceled because the payment for it was refundedprize_description (optional): Optional. Description of additional giveaway prize
Summary
Types
@type t() :: %ExGram.Model.GiveawayWinners{ additional_chat_count: integer() | nil, chat: ExGram.Model.Chat.t(), giveaway_message_id: integer(), only_new_members: boolean() | nil, premium_subscription_month_count: integer() | nil, prize_description: String.t() | nil, prize_star_count: integer() | nil, unclaimed_prize_count: integer() | nil, was_refunded: boolean() | nil, winner_count: integer(), winners: [ExGram.Model.User.t()], winners_selection_date: integer() }