This object describes a message that was deleted or is otherwise inaccessible to the bot.
Check the documentation of this model on Telegram Bot API
chat: Chat the message belonged tomessage_id: Unique message identifier inside the chatdate: Always 0. The field can be used to differentiate regular and inaccessible messages.
Summary
Types
@type t() :: %ExGram.Model.InaccessibleMessage{ chat: ExGram.Model.Chat.t(), date: integer(), message_id: integer() }