This object represents an inline keyboard that appears right next to the message it belongs to.
Check the documentation of this model on Telegram Bot API
inline_keyboard: Array of button rows, each represented by an Array of InlineKeyboardButton objects
Summary
Types
@type t() :: %ExGram.Model.InlineKeyboardMarkup{ inline_keyboard: [[ExGram.Model.InlineKeyboardButton.t()]] }