Represents a link to an article or web page.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be articleid: Unique identifier for this result, 1-64 Bytestitle: Title of the resultinput_message_content: Content of the message to be sentreply_markup (optional): Optional. Inline keyboard attached to the messageurl (optional): Optional. URL of the resultdescription (optional): Optional. Short description of the resultthumbnail_url (optional): Optional. Url of the thumbnail for the resultthumbnail_width (optional): Optional. Thumbnail widththumbnail_height (optional): Optional. Thumbnail height
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultArticle{ description: String.t() | nil, id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t(), reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, thumbnail_height: integer() | nil, thumbnail_url: String.t() | nil, thumbnail_width: integer() | nil, title: String.t(), type: String.t(), url: String.t() | nil }