Represents a link to a sticker stored on the Telegram servers. By default, this sticker will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the sticker.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be stickerid: Unique identifier for this result, 1-64 bytessticker_file_id: A valid file identifier of the stickerreply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the sticker
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultCachedSticker{ id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, sticker_file_id: String.t(), type: String.t() }