Represents a contact with a phone number. By default, this contact will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the contact.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be contactid: Unique identifier for this result, 1-64 Bytesphone_number: Contact's phone numberfirst_name: Contact's first namelast_name (optional): Optional. Contact's last namevcard (optional): Optional. Additional data about the contact in the form of a vCard, 0-2048 bytesreply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the contactthumbnail_url (optional): Optional. Url of the thumbnail for the resultthumbnail_width (optional): Optional. Thumbnail widththumbnail_height (optional): Optional. Thumbnail height
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultContact{ first_name: String.t(), id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, last_name: String.t() | nil, phone_number: String.t(), reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, thumbnail_height: integer() | nil, thumbnail_url: String.t() | nil, thumbnail_width: integer() | nil, type: String.t(), vcard: String.t() | nil }