Represents a location on a map. By default, the location will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the location.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be locationid: Unique identifier for this result, 1-64 Byteslatitude: Location latitude in degreeslongitude: Location longitude in degreestitle: Location titlehorizontal_accuracy (optional): Optional. The radius of uncertainty for the location, measured in meters; 0-1500live_period (optional): Optional. Period in seconds during which the location can be updated, should be between 60 and 86400, or 0x7FFFFFFF for live locations that can be edited indefinitely.heading (optional): Optional. For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.proximity_alert_radius (optional): Optional. For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.reply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the locationthumbnail_url (optional): Optional. Url of the thumbnail for the resultthumbnail_width (optional): Optional. Thumbnail widththumbnail_height (optional): Optional. Thumbnail height
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultLocation{ heading: integer() | nil, horizontal_accuracy: float() | nil, id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, latitude: float(), live_period: integer() | nil, longitude: float(), proximity_alert_radius: integer() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, thumbnail_height: integer() | nil, thumbnail_url: String.t() | nil, thumbnail_width: integer() | nil, title: String.t(), type: String.t() }