Represents a link to a video animation (H.264/MPEG-4 AVC video without sound). By default, this animated MPEG-4 file will be sent by the user with optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the animation.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be mpeg4_gifid: Unique identifier for this result, 1-64 bytesmpeg4_url: A valid URL for the MPEG4 filethumbnail_url: URL of the static (JPEG or GIF) or animated (MPEG4) thumbnail for the resultmpeg4_width (optional): Optional. Video widthmpeg4_height (optional): Optional. Video heightmpeg4_duration (optional): Optional. Video duration in secondsthumbnail_mime_type (optional): Optional. MIME type of the thumbnail, must be one of "image/jpeg”, "image/gif”, or "video/mp4”. Defaults to "image/jpeg”title (optional): Optional. Title for the resultcaption (optional): Optional. Caption of the MPEG-4 file to be sent, 0-1024 characters after entities parsingparse_mode (optional): Optional. Mode for parsing entities in the caption. See formatting options for more details.caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_modeshow_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message mediareply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the video animation
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultMpeg4Gif{ caption: String.t() | nil, caption_entities: [ExGram.Model.MessageEntity.t()] | nil, id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, mpeg4_duration: integer() | nil, mpeg4_height: integer() | nil, mpeg4_url: String.t(), mpeg4_width: integer() | nil, parse_mode: String.t() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, show_caption_above_media: boolean() | nil, thumbnail_mime_type: String.t() | nil, thumbnail_url: String.t(), title: String.t() | nil, type: String.t() }