Represents a link to a photo. By default, this photo will be sent by the user with optional caption. Alternatively, you can use input_message_content to send a message with the specified content instead of the photo.
Check the documentation of this model on Telegram Bot API
type: Type of the result, must be photoid: Unique identifier for this result, 1-64 bytesphoto_url: A valid URL of the photo. Photo must be in JPEG format. Photo size must not exceed 5MBthumbnail_url: URL of the thumbnail for the photophoto_width (optional): Optional. Width of the photophoto_height (optional): Optional. Height of the phototitle (optional): Optional. Title for the resultdescription (optional): Optional. Short description of the resultcaption (optional): Optional. Caption of the photo to be sent, 0-1024 characters after entities parsingparse_mode (optional): Optional. Mode for parsing entities in the photo caption. See formatting options for more details.caption_entities (optional): Optional. List of special entities that appear in the caption, which can be specified instead of parse_modeshow_caption_above_media (optional): Optional. Pass True, if the caption must be shown above the message mediareply_markup (optional): Optional. Inline keyboard attached to the messageinput_message_content (optional): Optional. Content of the message to be sent instead of the photo
Summary
Types
@type t() :: %ExGram.Model.InlineQueryResultPhoto{ caption: String.t() | nil, caption_entities: [ExGram.Model.MessageEntity.t()] | nil, description: String.t() | nil, id: String.t(), input_message_content: ExGram.Model.InputMessageContent.t() | nil, parse_mode: String.t() | nil, photo_height: integer() | nil, photo_url: String.t(), photo_width: integer() | nil, reply_markup: ExGram.Model.InlineKeyboardMarkup.t() | nil, show_caption_above_media: boolean() | nil, thumbnail_url: String.t(), title: String.t() | nil, type: String.t() }