Describes a checklist to create.
Check the documentation of this model on Telegram Bot API
title: Title of the checklist; 1-255 characters after entities parsingtasks: List of 1-30 tasks in the checklistparse_mode (optional): Optional. Mode for parsing entities in the title. See formatting options for more details.title_entities (optional): Optional. List of special entities that appear in the title, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed.others_can_add_tasks (optional): Optional. Pass True if other users can add tasks to the checklistothers_can_mark_tasks_as_done (optional): Optional. Pass True if other users can mark tasks as done or not done in the checklist
Summary
Types
@type t() :: %ExGram.Model.InputChecklist{ others_can_add_tasks: boolean() | nil, others_can_mark_tasks_as_done: boolean() | nil, parse_mode: String.t() | nil, tasks: [ExGram.Model.InputChecklistTask.t()], title: String.t(), title_entities: [ExGram.Model.MessageEntity.t()] | nil }