Represents the content of a contact message to be sent as the result of an inline query.
Check the documentation of this model on Telegram Bot API
phone_number: Contact's phone numberfirst_name: Contact's first namelast_name (optional): Optional. Contact's last namevcard (optional): Optional. Additional data about the contact in the form of a vCard, 0-2048 bytes