Represents the content of a venue message to be sent as the result of an inline query.
Check the documentation of this model on Telegram Bot API
latitude: Latitude of the venue in degreeslongitude: Longitude of the venue in degreestitle: Name of the venueaddress: Address of the venuefoursquare_id (optional): Optional. Foursquare identifier of the venue, if knownfoursquare_type (optional): Optional. Foursquare type of the venue, if known. (For example, "arts_entertainment/default”, "arts_entertainment/aquarium” or "food/icecream”.)google_place_id (optional): Optional. Google Places identifier of the venuegoogle_place_type (optional): Optional. Google Places type of the venue. (See supported types.)