This object contains basic information about an invoice.
Check the documentation of this model on Telegram Bot API
title: Product namedescription: Product descriptionstart_parameter: Unique bot deep-linking parameter that can be used to generate this invoicecurrency: Three-letter ISO 4217 currency code, or "XTR” for payments in Telegram Starstotal_amount: Total price in the smallest units of the currency (integer, not float/double). For example, for a price of US$ 1.45 pass amount = 145. See the exp parameter in currencies.json, it shows the number of digits past the decimal point for each currency (2 for the majority of currencies).