This object defines the parameters for the creation of a managed bot. Information about the created bot will be shared with the bot using the update managed_bot and a Message with the field managed_bot_created.
Check the documentation of this model on Telegram Bot API
request_id: Signed 32-bit identifier of the request. Must be unique within the messagesuggested_name (optional): Optional. Suggested name for the botsuggested_username (optional): Optional. Suggested username for the bot