This object represents a point on the map.
Check the documentation of this model on Telegram Bot API
latitude: Latitude as defined by the senderlongitude: Longitude as defined by the senderhorizontal_accuracy (optional): Optional. The radius of uncertainty for the location, measured in meters; 0-1500live_period (optional): Optional. Time relative to the message sending date, during which the location can be updated; in seconds. For active live locations only.heading (optional): Optional. The direction in which user is moving, in degrees; 1-360. For active live locations only.proximity_alert_radius (optional): Optional. The maximum distance for proximity alerts about approaching another chat member, in meters. For sent live locations only.