Describes the physical address of a location.
Check the documentation of this model on Telegram Bot API
country_code: The two-letter ISO 3166-1 alpha-2 country code of the country where the location is locatedstate (optional): Optional. State of the locationcity (optional): Optional. City of the locationstreet (optional): Optional. Street address of the location