This object contains information about the creation, token update, or owner update of a bot that is managed by the current bot.
Check the documentation of this model on Telegram Bot API
user: User that created the botbot: Information about the bot. Token of the bot can be fetched using the method getManagedBotToken.
Summary
Types
@type t() :: %ExGram.Model.ManagedBotUpdated{ bot: ExGram.Model.User.t(), user: ExGram.Model.User.t() }