Describes that no specific value for the menu button was set.
Check the documentation of this model on Telegram Bot API
type: Type of the button, must be default
Summary
Types
@type t() :: %ExGram.Model.MenuButtonDefault{type: String.t()}
Describes that no specific value for the menu button was set.
Check the documentation of this model on Telegram Bot API
type: Type of the button, must be default@type t() :: %ExGram.Model.MenuButtonDefault{type: String.t()}