This object represents a service message about a change in auto-delete timer settings.
Check the documentation of this model on Telegram Bot API
message_auto_delete_time: New auto-delete time for messages in the chat; in seconds
Summary
Types
@type t() :: %ExGram.Model.MessageAutoDeleteTimerChanged{ message_auto_delete_time: integer() }