The message was originally sent on behalf of a chat to a group chat.
Check the documentation of this model on Telegram Bot API
type: Type of the message origin, always "chat”date: Date the message was sent originally in Unix timesender_chat: Chat that sent the message originallyauthor_signature (optional): Optional. For messages originally sent by an anonymous chat administrator, original message author signature
Summary
Types
@type t() :: %ExGram.Model.MessageOriginChat{ author_signature: String.t() | nil, date: integer(), sender_chat: ExGram.Model.Chat.t(), type: String.t() }