The message was originally sent by an unknown user.
Check the documentation of this model on Telegram Bot API
type: Type of the message origin, always "hidden_user”date: Date the message was sent originally in Unix timesender_user_name: Name of the user that sent the message originally