The message was originally sent by a known user.
Check the documentation of this model on Telegram Bot API
type: Type of the message origin, always "user”date: Date the message was sent originally in Unix timesender_user: User that sent the message originally
Summary
Types
@type t() :: %ExGram.Model.MessageOriginUser{ date: integer(), sender_user: ExGram.Model.User.t(), type: String.t() }