This object represents reaction changes on a message with anonymous reactions.
Check the documentation of this model on Telegram Bot API
chat: The chat containing the messagemessage_id: Unique message identifier inside the chatdate: Date of the change in Unix timereactions: List of reactions that are present on the message
Summary
Types
@type t() :: %ExGram.Model.MessageReactionCountUpdated{ chat: ExGram.Model.Chat.t(), date: integer(), message_id: integer(), reactions: [ExGram.Model.ReactionCount.t()] }