Describes a regular gift owned by a user or a chat.
Check the documentation of this model on Telegram Bot API
type: Type of the gift, always "regular”gift: Information about the regular giftsend_date: Date the gift was sent in Unix timeowned_gift_id (optional): Optional. Unique identifier of the gift for the bot; for gifts received on behalf of business accounts onlysender_user (optional): Optional. Sender of the gift if it is a known usertext (optional): Optional. Text of the message that was added to the giftentities (optional): Optional. Special entities that appear in the textis_private (optional): Optional. True, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see themis_saved (optional): Optional. True, if the gift is displayed on the account's profile page; for gifts received on behalf of business accounts onlycan_be_upgraded (optional): Optional. True, if the gift can be upgraded to a unique gift; for gifts received on behalf of business accounts onlywas_refunded (optional): Optional. True, if the gift was refunded and isn't available anymoreconvert_star_count (optional): Optional. Number of Telegram Stars that can be claimed by the receiver instead of the gift; omitted if the gift cannot be converted to Telegram Stars; for gifts received on behalf of business accounts onlyprepaid_upgrade_star_count (optional): Optional. Number of Telegram Stars that were paid for the ability to upgrade the giftis_upgrade_separate (optional): Optional. True, if the gift's upgrade was purchased after the gift was sent; for gifts received on behalf of business accounts onlyunique_gift_number (optional): Optional. Unique number reserved for this gift when upgraded. See the number field in UniqueGift
Summary
Types
@type t() :: %ExGram.Model.OwnedGiftRegular{ can_be_upgraded: boolean() | nil, convert_star_count: integer() | nil, entities: [ExGram.Model.MessageEntity.t()] | nil, gift: ExGram.Model.Gift.t(), is_private: boolean() | nil, is_saved: boolean() | nil, is_upgrade_separate: boolean() | nil, owned_gift_id: String.t() | nil, prepaid_upgrade_star_count: integer() | nil, send_date: integer(), sender_user: ExGram.Model.User.t() | nil, text: String.t() | nil, type: String.t(), unique_gift_number: integer() | nil, was_refunded: boolean() | nil }