Describes a unique gift received and owned by a user or a chat.
Check the documentation of this model on Telegram Bot API
type: Type of the gift, always "unique”gift: Information about the unique giftsend_date: Date the gift was sent in Unix timeowned_gift_id (optional): Optional. Unique identifier of the received gift for the bot; for gifts received on behalf of business accounts onlysender_user (optional): Optional. Sender of the gift if it is a known useris_saved (optional): Optional. True, if the gift is displayed on the account's profile page; for gifts received on behalf of business accounts onlycan_be_transferred (optional): Optional. True, if the gift can be transferred to another owner; for gifts received on behalf of business accounts onlytransfer_star_count (optional): Optional. Number of Telegram Stars that must be paid to transfer the gift; omitted if the bot cannot transfer the giftnext_transfer_date (optional): Optional. Point in time (Unix timestamp) when the gift can be transferred. If it is in the past, then the gift can be transferred now
Summary
Types
@type t() :: %ExGram.Model.OwnedGiftUnique{ can_be_transferred: boolean() | nil, gift: ExGram.Model.UniqueGift.t(), is_saved: boolean() | nil, next_transfer_date: integer() | nil, owned_gift_id: String.t() | nil, send_date: integer(), sender_user: ExGram.Model.User.t() | nil, transfer_star_count: integer() | nil, type: String.t() }