Contains the list of gifts received and owned by a user or a chat.
Check the documentation of this model on Telegram Bot API
total_count: The total number of gifts owned by the user or the chatgifts: The list of giftsnext_offset (optional): Optional. Offset for the next request. If empty, then there are no more results
Summary
Types
@type t() :: %ExGram.Model.OwnedGifts{ gifts: [ExGram.Model.OwnedGift.t()], next_offset: String.t() | nil, total_count: integer() }