Describes the paid media added to a message.
Check the documentation of this model on Telegram Bot API
star_count: The number of Telegram Stars that must be paid to buy access to the mediapaid_media: Information about the paid media
Summary
Types
@type t() :: %ExGram.Model.PaidMediaInfo{ paid_media: [ExGram.Model.PaidMedia.t()], star_count: integer() }