The paid media isn't available before the payment.
Check the documentation of this model on Telegram Bot API
type: Type of the paid media, always "preview”width (optional): Optional. Media width as defined by the senderheight (optional): Optional. Media height as defined by the senderduration (optional): Optional. Duration of the media in seconds as defined by the sender