Describes a service message about a change in the price of paid messages within a chat.
Check the documentation of this model on Telegram Bot API
paid_message_star_count: The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message
Summary
Types
@type t() :: %ExGram.Model.PaidMessagePriceChanged{paid_message_star_count: integer()}