Represents an issue in one of the data fields that was provided by the user. The error is considered resolved when the field's value changes.
Check the documentation of this model on Telegram Bot API
source: Error source, must be datatype: The section of the user's Telegram Passport which has the error, one of "personal_details”, "passport”, "driver_license”, "identity_card”, "internal_passport”, "address”field_name: Name of the data field which has the errordata_hash: Base64-encoded data hashmessage: Error message