Represents an issue with a document scan. The error is considered resolved when the file with the document scan changes.
Check the documentation of this model on Telegram Bot API
source: Error source, must be filetype: The section of the user's Telegram Passport which has the issue, one of "utility_bill”, "bank_statement”, "rental_agreement”, "passport_registration”, "temporary_registration”file_hash: Base64-encoded file hashmessage: Error message