Represents an issue with the front side of a document. The error is considered resolved when the file with the front side of the document changes.
Check the documentation of this model on Telegram Bot API
source: Error source, must be front_sidetype: The section of the user's Telegram Passport which has the issue, one of "passport”, "driver_license”, "identity_card”, "internal_passport”file_hash: Base64-encoded hash of the file with the front side of the documentmessage: Error message