Represents an issue with the reverse side of a document. The error is considered resolved when the file with reverse side of the document changes.
Check the documentation of this model on Telegram Bot API
source: Error source, must be reverse_sidetype: The section of the user's Telegram Passport which has the issue, one of "driver_license”, "identity_card”file_hash: Base64-encoded hash of the file with the reverse side of the documentmessage: Error message