Represents an issue in an unspecified place. The error is considered resolved when new data is added.
Check the documentation of this model on Telegram Bot API
source: Error source, must be unspecifiedtype: Type of element of the user's Telegram Passport which has the issueelement_hash: Base64-encoded element hashmessage: Error message