This object represents one size of a photo or a file / sticker thumbnail.
Check the documentation of this model on Telegram Bot API
file_id: Identifier for this file, which can be used to download or reuse the filefile_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.width: Photo widthheight: Photo heightfile_size (optional): Optional. File size in bytes