This object contains information about a poll.
Check the documentation of this model on Telegram Bot API
id: Unique poll identifierquestion: Poll question, 1-300 charactersoptions: List of poll optionstotal_voter_count: Total number of users that voted in the pollis_closed: True, if the poll is closedis_anonymous: True, if the poll is anonymoustype: Poll type, currently can be "regular” or "quiz”allows_multiple_answers: True, if the poll allows multiple answersquestion_entities (optional): Optional. Special entities that appear in the question. Currently, only custom emoji entities are allowed in poll questionscorrect_option_id (optional): Optional. 0-based identifier of the correct answer option. Available only for polls in the quiz mode, which are closed, or was sent (not forwarded) by the bot or to the private chat with the bot.explanation (optional): Optional. Text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, 0-200 charactersexplanation_entities (optional): Optional. Special entities like usernames, URLs, bot commands, etc. that appear in the explanationopen_period (optional): Optional. Amount of time in seconds the poll will be active after creationclose_date (optional): Optional. Point in time (Unix timestamp) when the poll will be automatically closed
Summary
Types
@type t() :: %ExGram.Model.Poll{ allows_multiple_answers: boolean(), close_date: integer() | nil, correct_option_id: integer() | nil, explanation: String.t() | nil, explanation_entities: [ExGram.Model.MessageEntity.t()] | nil, id: String.t(), is_anonymous: boolean(), is_closed: boolean(), open_period: integer() | nil, options: [ExGram.Model.PollOption.t()], question: String.t(), question_entities: [ExGram.Model.MessageEntity.t()] | nil, total_voter_count: integer(), type: String.t() }