ExGram.Model.PollOption (ex_gram v0.64.0)

Copy Markdown View Source

This object contains information about one answer option in a poll.

Check the documentation of this model on Telegram Bot API

  • text: Option text, 1-100 characters
  • voter_count: Number of users that voted for this option
  • text_entities (optional): Optional. Special entities that appear in the option text. Currently, only custom emoji entities are allowed in poll option texts

Summary

Types

t()

@type t() :: %ExGram.Model.PollOption{
  text: String.t(),
  text_entities: [ExGram.Model.MessageEntity.t()] | nil,
  voter_count: integer()
}

Functions

decode_as()