This object contains information about one answer option in a poll.
Check the documentation of this model on Telegram Bot API
text: Option text, 1-100 charactersvoter_count: Number of users that voted for this optiontext_entities (optional): Optional. Special entities that appear in the option text. Currently, only custom emoji entities are allowed in poll option texts
Summary
Types
@type t() :: %ExGram.Model.PollOption{ text: String.t(), text_entities: [ExGram.Model.MessageEntity.t()] | nil, voter_count: integer() }