Describes an inline message to be sent by a user of a Mini App.
Check the documentation of this model on Telegram Bot API
id: Unique identifier of the prepared messageexpiration_date: Expiration date of the prepared message, in Unix time. Expired prepared messages can no longer be used