Describes a keyboard button to be used by a user of a Mini App.
Check the documentation of this model on Telegram Bot API
id: Unique identifier of the keyboard button
Summary
Types
@type t() :: %ExGram.Model.PreparedKeyboardButton{id: String.t()}
Describes a keyboard button to be used by a user of a Mini App.
Check the documentation of this model on Telegram Bot API
id: Unique identifier of the keyboard button@type t() :: %ExGram.Model.PreparedKeyboardButton{id: String.t()}