This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.
Check the documentation of this model on Telegram Bot API
traveler: User that triggered the alertwatcher: User that set the alertdistance: The distance between the users
Summary
Types
@type t() :: %ExGram.Model.ProximityAlertTriggered{ distance: integer(), traveler: ExGram.Model.User.t(), watcher: ExGram.Model.User.t() }