Represents a reaction added to a message along with the number of times it was added.
Check the documentation of this model on Telegram Bot API
type: Type of the reactiontotal_count: Number of times the reaction was added
Summary
Types
@type t() :: %ExGram.Model.ReactionCount{ total_count: integer(), type: ExGram.Model.ReactionType.t() }