The withdrawal succeeded.
Check the documentation of this model on Telegram Bot API
type: Type of the state, always "succeeded”date: Date the withdrawal was completed in Unix timeurl: An HTTPS URL that can be used to see transaction details
The withdrawal succeeded.
Check the documentation of this model on Telegram Bot API
type: Type of the state, always "succeeded”date: Date the withdrawal was completed in Unix timeurl: An HTTPS URL that can be used to see transaction details