This object represents a sticker.
Check the documentation of this model on Telegram Bot API
file_id: Identifier for this file, which can be used to download or reuse the filefile_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.type: Type of the sticker, currently one of "regular”, "mask”, "custom_emoji”. The type of the sticker is independent from its format, which is determined by the fields is_animated and is_video.width: Sticker widthheight: Sticker heightis_animated: True, if the sticker is animatedis_video: True, if the sticker is a video stickerthumbnail (optional): Optional. Sticker thumbnail in the .WEBP or .JPG formatemoji (optional): Optional. Emoji associated with the stickerset_name (optional): Optional. Name of the sticker set to which the sticker belongspremium_animation (optional): Optional. For premium regular stickers, premium animation for the stickermask_position (optional): Optional. For mask stickers, the position where the mask should be placedcustom_emoji_id (optional): Optional. For custom emoji stickers, unique identifier of the custom emojineeds_repainting (optional): Optional. True, if the sticker must be repainted to a text color in messages, the color of the Telegram Premium badge in emoji status, white color on chat photos, or another appropriate color in other placesfile_size (optional): Optional. File size in bytes
Summary
Types
@type t() :: %ExGram.Model.Sticker{ custom_emoji_id: String.t() | nil, emoji: String.t() | nil, file_id: String.t(), file_size: integer() | nil, file_unique_id: String.t(), height: integer(), is_animated: boolean(), is_video: boolean(), mask_position: ExGram.Model.MaskPosition.t() | nil, needs_repainting: boolean() | nil, premium_animation: ExGram.Model.File.t() | nil, set_name: String.t() | nil, thumbnail: ExGram.Model.PhotoSize.t() | nil, type: String.t(), width: integer() }