This object represents a sticker set.
Check the documentation of this model on Telegram Bot API
name: Sticker set nametitle: Sticker set titlesticker_type: Type of stickers in the set, currently one of "regular”, "mask”, "custom_emoji”stickers: List of all set stickersthumbnail (optional): Optional. Sticker set thumbnail in the .WEBP, .TGS, or .WEBM format
Summary
Types
@type t() :: %ExGram.Model.StickerSet{ name: String.t(), sticker_type: String.t(), stickers: [ExGram.Model.Sticker.t()], thumbnail: ExGram.Model.PhotoSize.t() | nil, title: String.t() }