Describes a story area pointing to an HTTP or tg:// link. Currently, a story can have up to 3 link areas.
Check the documentation of this model on Telegram Bot API
type: Type of the area, always "link”url: HTTP or tg:// URL to be opened when the area is clicked