Describes a story area pointing to a unique gift. Currently, a story can have at most 1 unique gift area.
Check the documentation of this model on Telegram Bot API
type: Type of the area, always "unique_gift”name: Unique name of the gift
Describes a story area pointing to a unique gift. Currently, a story can have at most 1 unique gift area.
Check the documentation of this model on Telegram Bot API
type: Type of the area, always "unique_gift”name: Unique name of the gift