Describes a story area containing weather information. Currently, a story can have up to 3 weather areas.
Check the documentation of this model on Telegram Bot API
type: Type of the area, always "weather”temperature: Temperature, in degree Celsiusemoji: Emoji representing the weatherbackground_color: A color of the area background in the ARGB format