Describes a service message about the approval of a suggested post.
Check the documentation of this model on Telegram Bot API
send_date: Date when the post will be publishedsuggested_post_message (optional): Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.price (optional): Optional. Amount paid for the post
Summary
Types
@type t() :: %ExGram.Model.SuggestedPostApproved{ price: ExGram.Model.SuggestedPostPrice.t() | nil, send_date: integer(), suggested_post_message: ExGram.Model.Message.t() | nil }