Describes a service message about the rejection of a suggested post.
Check the documentation of this model on Telegram Bot API
suggested_post_message (optional): Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.comment (optional): Optional. Comment with which the post was declined
Summary
Types
@type t() :: %ExGram.Model.SuggestedPostDeclined{ comment: String.t() | nil, suggested_post_message: ExGram.Model.Message.t() | nil }