Describes a service message about a successful payment for a suggested post.
Check the documentation of this model on Telegram Bot API
currency: Currency in which the payment was made. Currently, one of "XTR” for Telegram Stars or "TON” for toncoinssuggested_post_message (optional): Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.amount (optional): Optional. The amount of the currency that was received by the channel in nanotoncoins; for payments in toncoins onlystar_amount (optional): Optional. The amount of Telegram Stars that was received by the channel; for payments in Telegram Stars only
Summary
Types
@type t() :: %ExGram.Model.SuggestedPostPaid{ amount: integer() | nil, currency: String.t(), star_amount: ExGram.Model.StarAmount.t() | nil, suggested_post_message: ExGram.Model.Message.t() | nil }