Describes a service message about a payment refund for a suggested post.
Check the documentation of this model on Telegram Bot API
reason: Reason for the refund. Currently, one of "post_deleted” if the post was deleted within 24 hours of being posted or removed from scheduled messages without being posted, or "payment_refunded” if the payer refunded their payment.suggested_post_message (optional): Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Summary
Types
@type t() :: %ExGram.Model.SuggestedPostRefunded{ reason: String.t(), suggested_post_message: ExGram.Model.Message.t() | nil }