This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.
Check the documentation of this model on Telegram Bot API
query (optional): Optional. The default inline query to be inserted in the input field. If left empty, only the bot's username will be insertedallow_user_chats (optional): Optional. True, if private chats with users can be chosenallow_bot_chats (optional): Optional. True, if private chats with bots can be chosenallow_group_chats (optional): Optional. True, if group and supergroup chats can be chosenallow_channel_chats (optional): Optional. True, if channel chats can be chosen