This object contains information about the quoted part of a message that is replied to by the given message.
Check the documentation of this model on Telegram Bot API
text: Text of the quoted part of a message that is replied to by the given messageposition: Approximate quote position in the original message in UTF-16 code units as specified by the senderentities (optional): Optional. Special entities that appear in the quote. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are kept in quotes.is_manual (optional): Optional. True, if the quote was chosen manually by the message sender. Otherwise, the quote was added automatically by the server.
Summary
Types
@type t() :: %ExGram.Model.TextQuote{ entities: [ExGram.Model.MessageEntity.t()] | nil, is_manual: boolean() | nil, position: integer(), text: String.t() }