Describes a transaction with a chat.
Check the documentation of this model on Telegram Bot API
type: Type of the transaction partner, always "chat”chat: Information about the chatgift (optional): Optional. The gift sent to the chat by the bot
Summary
Types
@type t() :: %ExGram.Model.TransactionPartnerChat{ chat: ExGram.Model.Chat.t(), gift: ExGram.Model.Gift.t() | nil, type: String.t() }