Describes a withdrawal transaction with Fragment.
Check the documentation of this model on Telegram Bot API
type: Type of the transaction partner, always "fragment”withdrawal_state (optional): Optional. State of the transaction if the transaction is outgoing
Summary
Types
@type t() :: %ExGram.Model.TransactionPartnerFragment{ type: String.t(), withdrawal_state: ExGram.Model.RevenueWithdrawalState.t() | nil }