Describes a transaction with an unknown source or recipient.
Check the documentation of this model on Telegram Bot API
type: Type of the transaction partner, always "other”
Summary
Types
@type t() :: %ExGram.Model.TransactionPartnerOther{type: String.t()}