Describes a withdrawal transaction to the Telegram Ads platform.
Check the documentation of this model on Telegram Bot API
type: Type of the transaction partner, always "telegram_ads”
Summary
Types
@type t() :: %ExGram.Model.TransactionPartnerTelegramAds{type: String.t()}