This object describes a unique gift that was upgraded from a regular gift.
Check the documentation of this model on Telegram Bot API
gift_id: Identifier of the regular gift from which the gift was upgradedbase_name: Human-readable name of the regular gift from which this unique gift was upgradedname: Unique name of the gift. This name can be used in https://t.me/nft/... links and story areasnumber: Unique number of the upgraded gift among gifts upgraded from the same regular giftmodel: Model of the giftsymbol: Symbol of the giftbackdrop: Backdrop of the giftis_premium (optional): Optional. True, if the original regular gift was exclusively purchaseable by Telegram Premium subscribersis_burned (optional): Optional. True, if the gift was used to craft another gift and isn't available anymoreis_from_blockchain (optional): Optional. True, if the gift is assigned from the TON blockchain and can't be resold or transferred in Telegramcolors (optional): Optional. The color scheme that can be used by the gift's owner for the chat's name, replies to messages and link previews; for business account gifts and gifts that are currently on sale onlypublisher_chat (optional): Optional. Information about the chat that published the gift
Summary
Types
@type t() :: %ExGram.Model.UniqueGift{ backdrop: ExGram.Model.UniqueGiftBackdrop.t(), base_name: String.t(), colors: ExGram.Model.UniqueGiftColors.t() | nil, gift_id: String.t(), is_burned: boolean() | nil, is_from_blockchain: boolean() | nil, is_premium: boolean() | nil, model: ExGram.Model.UniqueGiftModel.t(), name: String.t(), number: integer(), publisher_chat: ExGram.Model.Chat.t() | nil, symbol: ExGram.Model.UniqueGiftSymbol.t() }