This object describes the backdrop of a unique gift.
Check the documentation of this model on Telegram Bot API
name: Name of the backdropcolors: Colors of the backdroprarity_per_mille: The number of unique gifts that receive this backdrop for every 1000 gifts upgraded
Summary
Types
@type t() :: %ExGram.Model.UniqueGiftBackdrop{ colors: ExGram.Model.UniqueGiftBackdropColors.t(), name: String.t(), rarity_per_mille: integer() }