This object describes the colors of the backdrop of a unique gift.
Check the documentation of this model on Telegram Bot API
center_color: The color in the center of the backdrop in RGB formatedge_color: The color on the edges of the backdrop in RGB formatsymbol_color: The color to be applied to the symbol in RGB formattext_color: The color for the text on the backdrop in RGB format