This object contains information about the color scheme for a user's name, message replies and link previews based on a unique gift.
Check the documentation of this model on Telegram Bot API
model_custom_emoji_id: Custom emoji identifier of the unique gift's modelsymbol_custom_emoji_id: Custom emoji identifier of the unique gift's symbollight_theme_main_color: Main color used in light themes; RGB formatlight_theme_other_colors: List of 1-3 additional colors used in light themes; RGB formatdark_theme_main_color: Main color used in dark themes; RGB formatdark_theme_other_colors: List of 1-3 additional colors used in dark themes; RGB format