Describes a service message about a unique gift that was sent or received.
Check the documentation of this model on Telegram Bot API
gift: Information about the giftorigin: Origin of the gift. Currently, either "upgrade” for gifts upgraded from regular gifts, "transfer” for gifts transferred from other users or channels, "resale” for gifts bought from other users, "gifted_upgrade” for upgrades purchased after the gift was sent, or "offer” for gifts bought or sold through gift purchase offerslast_resale_currency (optional): Optional. For gifts bought from other users, the currency in which the payment for the gift was done. Currently, one of "XTR” for Telegram Stars or "TON” for toncoins.last_resale_amount (optional): Optional. For gifts bought from other users, the price paid for the gift in either Telegram Stars or nanotoncoinsowned_gift_id (optional): Optional. Unique identifier of the received gift for the bot; only present for gifts received on behalf of business accountstransfer_star_count (optional): Optional. Number of Telegram Stars that must be paid to transfer the gift; omitted if the bot cannot transfer the giftnext_transfer_date (optional): Optional. Point in time (Unix timestamp) when the gift can be transferred. If it is in the past, then the gift can be transferred now