This object describes the symbol shown on the pattern of a unique gift.
Check the documentation of this model on Telegram Bot API
name: Name of the symbolsticker: The sticker that represents the unique giftrarity_per_mille: The number of unique gifts that receive this model for every 1000 gifts upgraded
Summary
Types
@type t() :: %ExGram.Model.UniqueGiftSymbol{ name: String.t(), rarity_per_mille: integer(), sticker: ExGram.Model.Sticker.t() }