This object represents the audios displayed on a user's profile.
Check the documentation of this model on Telegram Bot API
total_count: Total number of profile audios for the target useraudios: Requested profile audios
Summary
Types
@type t() :: %ExGram.Model.UserProfileAudios{ audios: [ExGram.Model.Audio.t()], total_count: integer() }