This object represent a user's profile pictures.
Check the documentation of this model on Telegram Bot API
total_count: Total number of profile pictures the target user hasphotos: Requested profile pictures (in up to 4 sizes each)
Summary
Types
@type t() :: %ExGram.Model.UserProfilePhotos{ photos: [[ExGram.Model.PhotoSize.t()]], total_count: integer() }