This object describes the rating of a user based on their Telegram Star spendings.
Check the documentation of this model on Telegram Bot API
level: Current level of the user, indicating their reliability when purchasing digital goods and services. A higher level suggests a more trustworthy customer; a negative level is likely reason for concern.rating: Numerical value of the user's rating; the higher the rating, the bettercurrent_level_rating: The rating value required to get the current levelnext_level_rating (optional): Optional. The rating value required to get to the next level; omitted if the maximum level was reached