This object represents a service message about a video chat ended in the chat.
Check the documentation of this model on Telegram Bot API
duration: Video chat duration in seconds
Summary
Types
@type t() :: %ExGram.Model.VideoChatEnded{duration: integer()}