This object represents a service message about new members invited to a video chat.
Check the documentation of this model on Telegram Bot API
users: New members that were invited to the video chat
Summary
Types
@type t() :: %ExGram.Model.VideoChatParticipantsInvited{ users: [ExGram.Model.User.t()] }