This object represents a video message (available in Telegram apps as of v.4.0).
Check the documentation of this model on Telegram Bot API
file_id: Identifier for this file, which can be used to download or reuse the filefile_unique_id: Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.length: Video width and height (diameter of the video message) as defined by the senderduration: Duration of the video in seconds as defined by the senderthumbnail (optional): Optional. Video thumbnailfile_size (optional): Optional. File size in bytes