Describes data sent from a Web App to the bot.
Check the documentation of this model on Telegram Bot API
data: The data. Be aware that a bad client can send arbitrary data in this field.button_text: Text of the web_app keyboard button from which the Web App was opened. Be aware that a bad client can send arbitrary data in this field.