Describes a Web App.
Check the documentation of this model on Telegram Bot API
url: An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps
Summary
Types
@type t() :: %ExGram.Model.WebAppInfo{url: String.t()}