Describes the current status of a webhook.
Check the documentation of this model on Telegram Bot API
url: Webhook URL, may be empty if webhook is not set uphas_custom_certificate: True, if a custom certificate was provided for webhook certificate checkspending_update_count: Number of updates awaiting deliveryip_address (optional): Optional. Currently used webhook IP addresslast_error_date (optional): Optional. Unix time for the most recent error that happened when trying to deliver an update via webhooklast_error_message (optional): Optional. Error message in human-readable format for the most recent error that happened when trying to deliver an update via webhooklast_synchronization_error_date (optional): Optional. Unix time of the most recent error that happened when trying to synchronize available updates with Telegram datacentersmax_connections (optional): Optional. The maximum allowed number of simultaneous HTTPS connections to the webhook for update deliveryallowed_updates (optional): Optional. A list of update types the bot is subscribed to. Defaults to all update types except chat_member
Summary
Types
@type t() :: %ExGram.Model.WebhookInfo{ allowed_updates: [String.t()] | nil, has_custom_certificate: boolean(), ip_address: String.t() | nil, last_error_date: integer() | nil, last_error_message: String.t() | nil, last_synchronization_error_date: integer() | nil, max_connections: integer() | nil, pending_update_count: integer(), url: String.t() }