Answer inline query response using ExGram.answer_inline_query/3.
This is a helper response type used by ExGram.Dsl to respond to inline queries
with article results.
Answer inline query response using ExGram.answer_inline_query/3.
This is a helper response type used by ExGram.Dsl to respond to inline queries
with article results.